from ApiMethod import ApiMethod


class Stories(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Stories, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'stories.'

    def banOwner(self, owners_ids: str = None) -> dict:
        """
        Позволяет скрыть из ленты новостей истории от выбранных источников.

        :param owners_ids: список идентификаторов источников.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'banOwner'
        return self._call(method_name, params)

    def delete(self, owner_id: str = None, story_id: str = None) -> dict:
        """
        Удаляет историю.

        :param owner_id: идентификатор владельца истории.
        :param story_id: идентификатор истории.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def get(self, owner_id: str = None, extended: str = None, fields: str = None) -> dict:
        """
        Возвращает истории, доступные для текущего пользователя.

        :param owner_id: идентификатор пользователя, истории которого необходимо получить.
        :param extended: 1 — возвращать в ответе дополнительную информацию о профилях пользователей.
        :param fields:

        :return: После успешного выполнения возвращает объект, содержащий число подборок в поле count и массив
            подборок историй в поле items. Каждая подборка — массив историй от одного владельца.  Если был задан
            параметр extended=1, дополнительно возвращает массив объектов пользователей в поле profiles (array) и
            сообществ в поле groups (array)
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getBanned(self, extended: str = None, fields: str = None) -> dict:
        """
        Возвращает список источников историй, скрытых из ленты текущего пользователя.

        :param extended: 1 — возвращать расширенную информацию о пользователях и сообществах.
        :param fields: дополнительные поля пользователей и сообществ, которые необходимо вернуть.

        :return: После успешного выполнения возвращает общее количество скрытых источников в поле count (integer)
            и их идентификаторы в массиве items. Если extended = 1, items содержит два поля:   profiles (array) —
            массив объектов, описывающих пользователей;  groups (array) — массив объектов, описывающих сообщества
        """

        params = locals()
        method_name = self._base_method + 'getBanned'
        return self._call(method_name, params)

    def getById(self, stories: str = None, extended: str = None, fields: str = None) -> dict:
        """
        Возвращает информацию об истории по её идентификатору.

        :param stories: перечисленные через запятую идентификаторы, которые представляют собой идущие через знак
            подчеркивания идентификаторы владельцев историй и идентификаторы самих историй.   Пример значения
            stories: 93388_21539,93388_20904
        :param extended: 1 — возвращать в ответе дополнительную информацию о пользователях.
        :param fields: дополнительные поля профилей и сообществ, которые необходимо вернуть в ответе.

        :return: После успешного выполнения возвращает объект, содержащий число историй в поле count и массив
            объектов историй в поле items.  Если был задан параметр extended = 1, дополнительно возвращает массив
            объектов пользователей в поле profiles и объектов сообществ в поле groups
        """

        params = locals()
        method_name = self._base_method + 'getById'
        return self._call(method_name, params)

    def getPhotoUploadServer(self, add_to_news: str = None, user_ids: str = None, reply_to_story: str = None,
                             link_text: str = None, link_url: str = None, group_id: str = None,
                             clickable_stickers: str = None) -> dict:
        """
        Позволяет получить адрес для загрузки истории с фотографией.

        :param add_to_news: 1 — разместить историю в новостях. Обязательно, если не указан user_ids
        :param user_ids: идентификаторы пользователей, которые будут видеть историю (для отправки в личном
            сообщении). Обязательно, если add_to_news не передан.
        :param reply_to_story: идентификатор истории, в ответ на которую создается новая.
        :param link_text: текст ссылки для перехода из истории (только для историй сообществ). Возможные
            значения:   to_store — «В магазин»;  vote — «Голосовать»;  more — «Ещё»;  book — «Забронировать»;  order
            — «Заказать»;  enroll — «Записаться»;  fill — «Заполнить»;  signup — «Зарегистрироваться»;  buy —
            «Купить»;  ticket — «Купить билет»;  write — «Написать»;  open — «Открыть»;  learn_more — «Подробнее» (по
            умолчанию);  view — «Посмотреть»;  go_to — «Перейти»;  contact — «Связаться»;  watch — «Смотреть»;  play
            — «Слушать»;  install — «Установить»;  read — «Читать».
        :param link_url: адрес ссылки для перехода из истории. Допустимы только внутренние ссылки https://vk.com.
        :param group_id: идентификатор сообщества, в которое должна быть загружена история (при работе с ключом
            доступа пользователя).  Обратите внимание — загрузка историй доступна только для верифицированных
            сообществ и для сообществ, отмеченных «огоньком».
        :param clickable_stickers: объект кликабельного стикера.

        :return: После успешного выполнения возвращает объект, содержащий следующие поля:   upload_url (string) —
            адрес сервера для загрузки файла;  user_ids (array) — идентификаторы пользователей, которые могут видеть
            историю
        """

        params = locals()
        method_name = self._base_method + 'getPhotoUploadServer'
        return self._call(method_name, params)

    def getReplies(self, owner_id: str = None, story_id: str = None, access_key: str = None, extended: str = None,
                   fields: str = None) -> dict:
        """
        Позволяет получить ответы на историю.

        :param owner_id: идентификатор владельца истории.
        :param story_id: идентификатор истории.
        :param access_key: ключ доступа для приватного объекта.
        :param extended: 1 — возвращать дополнительную информацию о профилях и сообществах.
        :param fields: дополнительные поля профилей и сообществ, которые необходимо вернуть в ответе.

        :return: После успешного выполнения возвращает объект, содержащий число подборок в поле count и массив
            подборок историй в поле items. Каждая подборка — массив историй от одного владельца.  Если был задан
            параметр extended=1, дополнительно возвращает массив объектов пользователей в поле profiles (array) и
            сообществ в поле groups (array)
        """

        params = locals()
        method_name = self._base_method + 'getReplies'
        return self._call(method_name, params)

    def getStats(self, owner_id: str = None, story_id: str = None) -> dict:
        """
        Возвращает статистику истории.

        :param owner_id: идентификатор владельца истории.
        :param story_id: идентификатор истории.

        :return: Возвращает объект, который содержит следующие поля:   views (object) — просмотры. Содержит поля:
            state (string) — доступность значения (on — доступно, off — недоступно);  count (integer) — значение
            счётчика;   replies (object) — ответы на историю. Содержит поля:   state (string) — доступность значения
            (on — доступно, off — недоступно);  count (integer) — значение счётчика;   answer (object) — показывает
            сколько раз ответили на эту историю сообщением через поле под историей. Не путать с ответами на историю.
            state (string) — доступность значения (on — доступно, off — недоступно);  count (integer) — значение
            счётчика;   shares (object) — расшаривания истории. Содержит поля:   state (string) — доступность
            значения (on — доступно, off — недоступно);  count (integer) — значение счётчика;   subscribers (object)
            — новые подписчики. Содержит поля:   state (string) — доступность значения (on — доступно, off —
            недоступно);  count (integer) — значение счётчика;   bans (object) — скрытия истории. Содержит поля:
            state (string) — доступность значения (on — доступно, off — недоступно);  count (integer) — значение
            счётчика;   open_link (object) — переходы по ссылке. Содержит поля:   state (string) — доступность
            значения (on — доступно, hidden — недоступно);  count (integer) — значение счётчика
        """

        params = locals()
        method_name = self._base_method + 'getStats'
        return self._call(method_name, params)

    def getVideoUploadServer(self, add_to_news: str = None, user_ids: str = None, reply_to_story: str = None,
                             link_text: str = None, link_url: str = None, group_id: str = None,
                             clickable_stickers: str = None) -> dict:
        """
        Позволяет получить адрес для загрузки видеозаписи в историю.

        :param add_to_news: 1 — разместить историю в новостях.
        :param user_ids: идентификаторы пользователей, которые будут видеть историю (для отправки в личном
            сообщении).
        :param reply_to_story: идентификатор истории, в ответ на которую создается новая.
        :param link_text: текст ссылки для перехода из истории (только для историй сообществ). Возможные
            значения:   to_store — «В магазин»;  vote — «Голосовать»;  more — «Ещё»;  book — «Забронировать»;  order
            — «Заказать»;  enroll — «Записаться»;  fill — «Заполнить»;  signup — «Зарегистрироваться»;  buy —
            «Купить»;  ticket — «Купить билет»;  write — «Написать»;  open — «Открыть»;  learn_more — «Подробнее» (по
            умолчанию);  view — «Посмотреть»;  go_to — «Перейти»;  contact — «Связаться»;  watch — «Смотреть»;  play
            — «Слушать»;  install — «Установить»;  read — «Читать»;  game — «Играть».
        :param link_url: адрес ссылки для перехода из истории.
        :param group_id: идентификатор сообщества, в которое должна быть загружена история (при работе с ключом
            доступа пользователя).  Обратите внимание — загрузка историй доступна только для верифицированных
            сообществ и для сообществ, отмеченных «огоньком».
        :param clickable_stickers: объект кликабельного стикера.

        :return: После успешного выполнения возвращает объект, содержащий следующие поля:   upload_url (string) —
            адрес сервера для загрузки файла;  user_ids (array) — идентификаторы пользователей, которые могут видеть
            историю
        """

        params = locals()
        method_name = self._base_method + 'getVideoUploadServer'
        return self._call(method_name, params)

    def getViewers(self, owner_id: str = None, story_id: str = None, count: str = None, offset: str = None,
                   extended: str = None) -> dict:
        """
        Возвращает список пользователей, просмотревших историю.

        :param owner_id: идентификатор владельца истории.
        :param story_id: идентификатор истории.
        :param count: максимальное число результатов в ответе.
        :param offset: сдвиг для получения определённого подмножества результатов.
        :param extended: 1 — возвращать в ответе расширенную информацию о пользователях.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и
            идентификаторы пользователей в поле items (array). Если extended = 1, поле items (array) содержит массив
            объектов пользователей
        """

        params = locals()
        method_name = self._base_method + 'getViewers'
        return self._call(method_name, params)

    def hideAllReplies(self, owner_id: str = None, group_id: str = None) -> dict:
        """
        Скрывает все ответы автора за последние сутки на истории текущего пользователя.

        :param owner_id: идентификатор пользователя, ответы от которого нужно скрыть.
        :param group_id:

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'hideAllReplies'
        return self._call(method_name, params)

    def hideReply(self, owner_id: str = None, story_id: str = None) -> dict:
        """
        Скрывает ответ на историю.

        :param owner_id: идентификатор владельца истории (ответной).
        :param story_id: идентификатор истории (ответной).

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'hideReply'
        return self._call(method_name, params)

    def search(self, q: str = None, place_id: str = None, latitude: str = None, longitude: str = None,
               radius: str = None, mentioned_id: str = None, count: str = None, extended: str = None,
               fields: str = None) -> dict:
        """
        Возвращает результаты поиска по историям.

        :param q: поисковый запрос.
        :param place_id: идентификатор места.
        :param latitude: географическая широта точки, в радиусе которой необходимо производить поиск, заданная в
            градусах (от -90 до 90).
        :param longitude: географическая долгота точки, в радиусе которой необходимо производить поиск, заданная
            в градусах (от -180 до 180).
        :param radius: радиус зоны поиска в метрах.
        :param mentioned_id: идентификатор упомянутого в истории пользователя или сообщества.
        :param count: количество историй, информацию о которых необходимо вернуть.
        :param extended: параметр, определяющий необходимость возвращать расширенную информацию о владельце
            истории. Возможные значения:   0 — возвращаются только идентификаторы;  1 — будут дополнительно
            возвращены имя и фамилия.   По умолчанию: 0.
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов историй в поле items.  Если был задан параметр extended=1, возвращает объекты profiles и groups,
            содержащие массивы объектов, описывающих пользователей и сообществ
        """

        params = locals()
        method_name = self._base_method + 'search'
        return self._call(method_name, params)

    def sendInteraction(self, access_key: str = None, message: str = None, is_broadcast: str = None,
                        is_anonymous: str = None) -> dict:
        """
        Отправляет фидбек на историю.

        :param access_key: ключ доступа пользователя, полученный при подписке. Возвращает событие
            VKWebAppSubscribeStoryApp.
        :param message: текст фидбека.
        :param is_broadcast: Возможные значения:   0 — фидбек виден только отправителю и автору истории;  1 —
            фидбек виден всем зрителям истории и автору.
        :param is_anonymous: Возможные значения:   0 — автор фидбека не анонимный;  1 — автор фидбека анонимный.

        :return
        """

        params = locals()
        method_name = self._base_method + 'sendInteraction'
        return self._call(method_name, params)

    def unbanOwner(self, owners_ids: str = None) -> dict:
        """
        Позволяет вернуть пользователя или сообщество в список отображаемых историй в ленте.

        :param owners_ids: список идентификаторов владельцев историй, разделённых запятой.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'unbanOwner'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Groups(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Groups, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'groups.'

    def addAddress(self, group_id: str = None, title: str = None, address: str = None, additional_address: str = None,
                   country_id: str = None, city_id: str = None, metro_id: str = None, latitude: str = None,
                   longitude: str = None, phone: str = None, work_info_status: str = None, timetable: str = None,
                   is_main_address: str = None) -> dict:
        """
        Позволяет добавить адрес в сообщество.  Список адресов может быть получен методом groups.getAddresses.  Для
        того, чтобы воспользоваться этим методом, Вы должны быть администратором сообщества

        :param group_id: идентификатор сообщества, в которое добавляется адрес.
        :param title: заголовок адреса
        :param address: строка адреса Невский проспект, дом 28
        :param additional_address: дополнительное описание адреса. Второй этаж, налево
        :param country_id: идентификатор страны. Для получения можно использовать database.getCountries
        :param city_id: идентификатор города. Для получения можно использовать database.getCities
        :param metro_id: идентификатор станции метро. Для получения можно использовать database.getMetroStations
        :param latitude: географическая широта отметки, заданная в градусах (от -90 до 90).
        :param longitude: географическая долгота отметки, заданная в градусах (от -180 до 180).
        :param phone: номер телефона
        :param work_info_status: тип расписания. Возможные значения:   no_information — нет информации о
            расписании;  temporarily_closed — временно закрыто;  always_opened — открыто круглосуточно;
            forever_closed — закрыто навсегда;  timetable — открыто в указанные часы работы. Для этого типа
            расписания необходимо передать параметр timetable;
        :param timetable: для типа timetable можно передать расписание в формате json. Время передается в минутах
            от 0 часов. Ключ по дню означает, что день рабочий. open_time, close_time - начало и конец рабочего дня.
            break_open_time, break_close_time — время перерыва. {    "mon": {      "open_time": 1080,
                "close_time": 1380    },    "tue": {      "open_time": 1080,      "close_time": 1380    },    "wed":
            {      "open_time": 1080,      "close_time": 1320    },    "thu": {      "open_time": 1080,
                "close_time": 1320    },    "fri": {      "open_time": 1080,      "close_time": 1320    },    "sat":
            {      "open_time": 1080,      "close_time": 1320,      "break_open_time": 1200,      "break_close_time":
            1230    }  }
        :param is_main_address: установить адрес основным. Информация об основном адресе сразу показывается в
            сообществе. Для получения информации об остальных адресах нужно перейти к списку адресов.

        :return
        """

        params = locals()
        method_name = self._base_method + 'addAddress'
        return self._call(method_name, params)

    def addCallbackServer(self, group_id: str = None, url: str = None, title: str = None,
                          secret_key: str = None) -> dict:
        """
        Добавляет сервер для Callback API в сообщество.

        :param group_id: идентификатор сообщества.
        :param url: URL сервера.
        :param title: название сервера.
        :param secret_key: секретный ключ.

        :return: После успешного выполнения возвращает идентификатор добавленного сервера в поле server_id
            (integer)
        """

        params = locals()
        method_name = self._base_method + 'addCallbackServer'
        return self._call(method_name, params)

    def addLink(self, group_id: str = None, link: str = None, text: str = None) -> dict:
        """
        Позволяет добавлять ссылки в сообщество.

        :param group_id: идентификатор сообщества, в которое добавляется ссылка.
        :param link: адрес ссылки.
        :param text: текст ссылки.

        :return: В случае успешного выполнения возвращает объект со следующими полями:   id (integer) —
            идентификатор ссылки;  url (string) — URL ссылки;  name (string) — название ссылки в блоке сообщества;
            edit_title (integer, [0,1]) — возвращается 1, если можно редактировать название ссылки (для внешних
            ссылок);  desc (string) — описание ссылки;  image_processing (integer, [1]) — возвращается 1, если превью
            находится в процессе обработки
        """

        params = locals()
        method_name = self._base_method + 'addLink'
        return self._call(method_name, params)

    def approveRequest(self, group_id: str = None, user_id: str = None) -> dict:
        """
        Позволяет одобрить заявку в группу от пользователя.

        :param group_id: идентификатор группы, заявку в которую необходимо одобрить.
        :param user_id: идентификатор пользователя, заявку которого необходимо одобрить.

        :return: В случае успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'approveRequest'
        return self._call(method_name, params)

    def ban(self, group_id: str = None, owner_id: str = None, end_date: str = None, reason: str = None,
            comment: str = None, comment_visible: str = None) -> dict:
        """
        Добавляет пользователя или группу в черный список сообщества.

        :param group_id: идентификатор сообщества.
        :param owner_id: идентификатор пользователя или сообщества, которое будет добавлено в черный список.
            Обратите внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" —
            например, owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param end_date: дата завершения срока действия бана в формате unixtime. Максимальный возможный срок
            окончания бана, который можно указать, — один год с его начала. Если параметр не указан, пользователь
            будет заблокирован навсегда.
        :param reason: причина бана:   0 — другое (по умолчанию);  1 — спам;  2 — оскорбление участников;  3
            — нецензурные выражения;  4 — сообщения не по теме.
        :param comment: текст комментария к бану.
        :param comment_visible: 1 – текст комментария будет отображаться пользователю.  0 – текст комментария не
            доступен пользователю. (по умолчанию)

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'ban'
        return self._call(method_name, params)

    def create(self, title: str = None, description: str = None, type: str = None, public_category: str = None,
               subtype: str = None) -> dict:
        """
        Создает новое сообщество.

        :param title: название сообщества.
        :param description: описание сообщества, (не учитывается при type=public).
        :param type: тип создаваемого сообщества:   group — группа;  event — мероприятие;  public — публичная
            страница.
        :param public_category: категория публичной страницы (только для type = public).
        :param subtype: вид публичной страницы (только при type=public):   1 — место или небольшая компания;  2 —
            компания, организация или веб-сайт;  3 — известная личность или коллектив;  4 — произведение или
            продукция.

        :return: После успешного выполнения возвращает объект, описывающий созданное сообщество
        """

        params = locals()
        method_name = self._base_method + 'create'
        return self._call(method_name, params)

    def deleteAddress(self, group_id: str = None, address_id: str = None) -> dict:
        """
        Удаляет адрес сообщества.

        :param group_id: Id группы
        :param address_id: Id адреса

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteAddress'
        return self._call(method_name, params)

    def deleteCallbackServer(self, group_id: str = None, server_id: str = None) -> dict:
        """
        Удаляет сервер для Callback API из сообщества.

        :param group_id: идентификатор сообщества.
        :param server_id: идентификатор сервера, который нужно удалить.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteCallbackServer'
        return self._call(method_name, params)

    def deleteLink(self, group_id: str = None, link_id: str = None) -> dict:
        """
        Позволяет удалить ссылки из сообщества.

        :param group_id: идентификатор сообщества, ссылки которого нужно удалить
        :param link_id: идентификатор ссылки, которую необходимо удалить

        :return: В случае успешного выполнения метод возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteLink'
        return self._call(method_name, params)

    def disableOnline(self, group_id: str = None) -> dict:
        """
        Выключает статус «онлайн» в сообществе.

        :param group_id: идентификатор сообщества.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'disableOnline'
        return self._call(method_name, params)

    def edit(self, group_id: str = None, title: str = None, description: str = None, screen_name: str = None,
             access: str = None, website: str = None, subject: str = None, email: str = None, phone: str = None,
             rss: str = None, event_start_date: str = None, event_finish_date: str = None, event_group_id: str = None,
             public_category: str = None, public_subcategory: str = None, public_date: str = None, wall: str = None,
             topics: str = None, photos: str = None, video: str = None, audio: str = None, links: str = None,
             events: str = None, places: str = None, contacts: str = None, docs: str = None, wiki: str = None,
             messages: str = None, articles: str = None, addresses: str = None, age_limits: str = None,
             market: str = None, market_comments: str = None, market_country: str = None, market_city: str = None,
             market_currency: str = None, market_contact: str = None, market_wiki: str = None,
             obscene_filter: str = None, obscene_stopwords: str = None, obscene_words: str = None,
             main_section: str = None, secondary_section: str = None, country: str = None, city: str = None,
             ads_easy_promote_disable_main_screen_button: str = None,
             ads_easy_promote_disable_promote_post_button: str = None) -> dict:
        """
        Редактирует сообщество.

        :param group_id: идентификатор сообщества.
        :param title: название сообщества.
        :param description: описание сообщества.
        :param screen_name: короткое имя сообщества.
        :param access: тип группы. Возможные значения:   0 — открытая;  1 — закрытая;  2 — частная.
        :param website: адрес сайта, который будет указан в информации о группе.
        :param subject: тематика сообщества. Возможные значения:   1 — авто/мото;  2 — активный отдых;  3 —
            бизнес;  4 — домашние животные;  5 — здоровье;  6 — знакомство и общение;  7 — игры;  8 — ИТ (компьютеры
            и софт);  9 — кино;  10 — красота и мода;  11 — кулинария;  12 — культура и искусство;  13 — литература;
            14 — мобильная связь и интернет;  15 — музыка;  16 — наука и техника;  17 — недвижимость;  18 — новости и
            СМИ;  19 — безопасность;  20 — образование;  21 — обустройство и ремонт;  22 — политика;  23 — продукты
            питания;  24 — промышленность;  25 — путешествия;  26 — работа;  27 — развлечения;  28 — религия;  29 —
            дом и семья;  30 — спорт;  31 — страхование;  32 — телевидение;  33 — товары и услуги;  34 — увлечения и
            хобби;  35 — финансы;  36 — фото;  37 — эзотерика;  38 — электроника и бытовая техника;  39 — эротика;
            40 — юмор;  41 — общество, гуманитарные науки;  42 — дизайн и графика.
        :param email: электронный адрес организатора (для мероприятий).
        :param phone: номер телефона организатора (для мероприятий).
        :param rss: адрес rss для импорта новостей (доступен только группам, получившим соответствующее
            разрешение, обратитесь в http://vk.com/support для получения разрешения).
        :param event_start_date: дата начала события.
        :param event_finish_date: дата окончания события.
        :param event_group_id: идентификатор группы, которая является организатором события (только для событий).
        :param public_category: категория публичной страницы.
        :param public_subcategory: подкатегория публичной станицы. Список подкатегорий можно получить методом
            groups.getSettings.
        :param public_date: дата основания компании, организации, которой посвящена публичная страница в виде
            строки формата "dd.mm.YYYY".
        :param wall: стена. Возможные значения:   0 — выключена;  1 — открытая;  2 — ограниченная (доступно
            только для групп и событий);  3 — закрытая (доступно только для групп и событий).
        :param topics: обсуждения. Возможные значения:   0 — выключены;  1 — открытые;  2 — ограниченные
            (доступно только для групп и событий).
        :param photos: фотографии. Возможные значения:   0 — выключены;  1 — открытые;  2 — ограниченные
            (доступно только для групп и событий).
        :param video: видеозаписи. Возможные значения:   0 — выключены;  1 — открытые;  2 — ограниченные
            (доступно только для групп и событий).
        :param audio: аудиозаписи. Возможные значения:   0 — выключены;  1 — открытые;  2 — ограниченные
            (доступно только для групп и событий).
        :param links: ссылки (доступно только для публичных страниц).  Возможные значения:   0 — выключены;  1 —
            включены.
        :param events: события (доступно только для публичных страниц).  Возможные значения:   0 — выключены;  1
            — включены.
        :param places: места (доступно только для публичных страниц). Возможные значения:   0 — выключены;  1 —
            включены.
        :param contacts: контакты (доступно только для публичных страниц). Возможные значения:   0 — выключены;
            1 — включены.
        :param docs: документы сообщества. Возможные значения:   0 — выключены;  1 — открытые;  2 — ограниченные
            (доступно только для групп и событий).
        :param wiki: wiki-материалы сообщества. Возможные значения:   0 — выключены;  1 — открытые;  2 —
            ограниченные (доступно только для групп и событий).
        :param messages: сообщения сообщества. Возможные значения:   0 — выключены;  1 — включены.
        :param articles:
        :param addresses:
        :param age_limits: возрастное ограничение для сообщества. Возможные значения:   1 — нет ограничений;  2 —
            16+;  3 — 18+.
        :param market: товары. Возможные значения:   0 — выключены;  1 — включены.
        :param market_comments: комментарии к товарам. Возможные значения:   0 — выключены;  1 — включены.
        :param market_country: регионы доставки товаров.
        :param market_city: города доставки товаров (в случае если указана одна страна).
        :param market_currency: идентификатор валюты магазина. Возможные значения:   643 — российский рубль;  980
            — украинская гривна;  398 — казахстанский тенге;  978 — евро;  840 — доллар США.
        :param market_contact: контакт для связи для продавцом.  Для использования сообщений сообщества следует
            включить их и передать значение 0.
        :param market_wiki: идентификатор wiki-страницы с описанием магазина.
        :param obscene_filter: фильтр нецензурных выражений в комментариях. Возможные значения:   0 — выключен;
            1 — включен.
        :param obscene_stopwords: фильтр по ключевым словам в комментариях. Возможные значения:   0 — выключен;
            1 — включен.
        :param obscene_words: ключевые слова для фильтра комментариев.
        :param main_section:
        :param secondary_section:
        :param country:
        :param city:
        :param ads_easy_promote_disable_main_screen_button:
        :param ads_easy_promote_disable_promote_post_button:

        :return: В случае успеха возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'edit'
        return self._call(method_name, params)

    def editAddress(self, group_id: str = None, address_id: str = None, title: str = None, address: str = None,
                    additional_address: str = None, country_id: str = None, city_id: str = None, metro_id: str = None,
                    latitude: str = None, longitude: str = None, phone: str = None, work_info_status: str = None,
                    timetable: str = None, is_main_address: str = None) -> dict:
        """
        Позволяет отредактировать адрес в сообществе.  Список адресов может быть получен методом groups.getAddresses.
        Для того, чтобы воспользоваться этим методом, Вы должны быть администратором сообщества

        :param group_id: идентификатор сообщества, в которое добавляется адрес.
        :param address_id: идентификатор адреса
        :param title: заголовок адреса
        :param address: строка адреса Невский проспект, дом 28
        :param additional_address: дополнительное описание адреса. Второй этаж, налево
        :param country_id: идентификатор страны. Для получения можно использовать database.getCountries
        :param city_id: идентификатор города. Для получения можно использовать database.getCities
        :param metro_id: идентификатор станции метро. Для получения можно использовать database.getMetroStations
        :param latitude: географическая широта отметки, заданная в градусах (от -90 до 90).
        :param longitude: географическая долгота отметки, заданная в градусах (от -180 до 180).
        :param phone: номер телефона
        :param work_info_status: тип расписания. Возможные значения:   no_information — нет информации о
            расписании;  temporarily_closed — временно закрыто;  always_opened — открыто круглосуточно;
            forever_closed — закрыто навсегда;  timetable — открыто в указанные часы работы. Для этого типа
            расписания необходимо передать параметр timetable;
        :param timetable: для типа timetable можно передать расписание в формате json. Время передается в минутах
            от 0 часов. Ключ по дню означает, что день рабочий. open_time, close_time — начало и конец рабочего дня.
            break_open_time, break_close_time - время перерыва {    "mon": {      "open_time": 1080,
                "close_time": 1380    },    "tue": {      "open_time": 1080,      "close_time": 1380    },    "wed":
            {      "open_time": 1080,      "close_time": 1320    },    "thu": {      "open_time": 1080,
                "close_time": 1320    },    "fri": {      "open_time": 1080,      "close_time": 1320    },    "sat":
            {      "open_time": 1080,      "close_time": 1320,      "break_open_time": 1200,      "break_close_time":
            1230    }  }
        :param is_main_address: установить адрес основным. Информация об основном адресе сразу показывается в
            сообществе. Для получения информации об остальных адресах нужно перейти к списку адресов.

        :return
        """

        params = locals()
        method_name = self._base_method + 'editAddress'
        return self._call(method_name, params)

    def editCallbackServer(self, group_id: str = None, server_id: str = None, url: str = None, title: str = None,
                           secret_key: str = None) -> dict:
        """
        Редактирует данные сервера для Callback API в сообществе.

        :param group_id: идентификатор сообщества.
        :param server_id: идентификатор сервера, данные которого нужно отредактировать.
        :param url: новый URL сервера.
        :param title: новое название сервера.
        :param secret_key: новый секретный ключ сервера.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editCallbackServer'
        return self._call(method_name, params)

    def editLink(self, group_id: str = None, link_id: str = None, text: str = None) -> dict:
        """
        Позволяет редактировать ссылки в сообществе.

        :param group_id: идентификатор сообщества, в которое добавляется ссылка.
        :param link_id: идентификатор ссылки.
        :param text: новый текст описания для ссылки.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editLink'
        return self._call(method_name, params)

    def editManager(self, group_id: str = None, user_id: str = None, role: str = None, is_contact: str = None,
                    contact_position: str = None, contact_phone: str = None, contact_email: str = None) -> dict:
        """
        Позволяет назначить/разжаловать руководителя в сообществе или изменить уровень его полномочий.

        :param group_id: идентификатор сообщества (указывается без знака «минус»).
        :param user_id: идентификатор пользователя, чьи полномочия в сообществе нужно изменить.
        :param role: уровень полномочий:   moderator — модератор;  editor — редактор;  administrator —
            администратор.   Если параметр не задан, с пользователя user_id снимаются полномочия руководителя.
        :param is_contact: отображать ли пользователя в блоке контактов сообщества.
        :param contact_position: должность пользователя, отображаемая в блоке контактов.
        :param contact_phone: телефон пользователя, отображаемый в блоке контактов.
        :param contact_email: email пользователя, отображаемый в блоке контактов.

        :return: В случае успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editManager'
        return self._call(method_name, params)

    def enableOnline(self, group_id: str = None) -> dict:
        """
        Включает статус «онлайн» в сообществе.

        :param group_id: идентификатор сообщества.

        :return: После успешного выполнения возращает 1
        """

        params = locals()
        method_name = self._base_method + 'enableOnline'
        return self._call(method_name, params)

    def get(self, user_id: str = None, extended: str = None, filter: str = None, fields: str = None, offset: str = None,
            count: str = None) -> dict:
        """
        Возвращает список сообществ указанного пользователя.

        :param user_id: идентификатор пользователя, информацию о сообществах которого требуется получить.
        :param extended: если указать в качестве этого параметра 1, то будет возвращена полная информация о
            группах пользователя. По умолчанию 0.
        :param filter: список фильтров сообществ, которые необходимо вернуть, перечисленные через запятую.
            Доступны значения admin, editor, moder, advertiser, groups, publics, events, hasAddress. По умолчанию
            возвращаются все сообщества пользователя.  При указании фильтра hasAddress вернутся сообщества, в которых
            указаны адреса в соответствующем блоке, admin будут возвращены сообщества, в которых пользователь
            является администратором, editor — администратором или редактором, moder — администратором, редактором
            или модератором, advertiser — рекламодателем. Если передано несколько фильтров, то их результат
            объединяется.
        :param fields: список дополнительных полей, которые необходимо вернуть. Возможные значения: city,
            country, place, description, wiki_page, members_count, counters, start_date, finish_date, can_post,
            can_see_all_posts, activity, status, contacts, links, fixed_post, verified, site, can_create_topic.
            Подробнее см. описание полей объекта group.  Обратите внимание, этот параметр учитывается только при
            extended=1.
        :param offset: смещение, необходимое для выборки определённого подмножества сообществ.
        :param count: количество сообществ, информацию о которых нужно вернуть.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count
            (integer) и массив идентификаторов сообщества в поле items ([integer]).  Если был задан параметр
            extended=1, возвращает объект, содержащий число результатов в поле count (integer) и массив объектов,
            описывающих сообщества, в поле items
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getAddresses(self, group_id: str = None, address_ids: str = None, latitude: str = None, longitude: str = None,
                     offset: str = None, count: str = None, fields: str = None) -> dict:
        """
        Возвращает адрес указанного сообщества.

        :param group_id: идентификатор сообщества.
        :param address_ids: перечисленные через запятую идентификаторы адресов, информацию о которых необходимо
            вернуть.
        :param latitude: географическая широта отметки, заданная в градусах (от -90 до 90).
        :param longitude: географическая долгота отметки, заданная в градусах (от -180 до 180).
        :param offset: смещение, необходимое для выборки определенного подмножества черного списка.
        :param count: количество адресов, которое необходимо вернуть.
        :param fields: список дополнительных полей сообществ, которые необходимо вернуть.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов адресов в поле items
        """

        params = locals()
        method_name = self._base_method + 'getAddresses'
        return self._call(method_name, params)

    def getBanned(self, group_id: str = None, offset: str = None, count: str = None, fields: str = None,
                  owner_id: str = None) -> dict:
        """
        Возвращает список забаненных пользователей и сообществ в сообществе.

        :param group_id: идентификатор сообщества.
        :param offset: смещение, необходимое для выборки определенного подмножества черного списка.
        :param count: количество пользователей, которое необходимо вернуть.
        :param fields: список дополнительных полей профилей и сообществ, которые необходимо вернуть.
        :param owner_id: идентификатор пользователя или сообщества из чёрного списка, информацию о котором нужно
            получить.

        :return: После успешного выполнения возвращает общее число результатов в поле count (integer) и
            информацию о пользователях и сообществах из чёрного списка в поле items (array). Каждый объект в массиве
            items содержит поля:   type (string) — тип. Возможные значения:   group — сообщество;  profile —
            пользователь.   group (object) — информация о сообществе (для type = group). Объект сообщества.  profile
            (object) — информация о пользователе (для type = profile). Объект пользователя.  ban_info (object) —
            информация о блокировке в сообществе. Объект, который содержит поля:   Объект ban_info — информация о
            внесении в черный список сообщества.  admin_id идентификатор администратора, который добавил пользователя
            или сообщество в черный список.   integer date дата добавления в черный список в формате Unixtime.
            integer reason причина добавления в черный список. Возможные значения:   0 — другое (по умолчанию);  1 —
            спам;  2 — оскорбление участников;  3 — нецензурные выражения;  4 — сообщения не по теме.    integer
            comment текст комментария.   string end_date дата окончания блокировки (0 — блокировка вечная).   intege
        """

        params = locals()
        method_name = self._base_method + 'getBanned'
        return self._call(method_name, params)

    def getById(self, group_ids: str = None, group_id: str = None, fields: str = None) -> dict:
        """
        Возвращает информацию о заданном сообществе или о нескольких сообществах.

        :param group_ids: идентификаторы или короткие имена сообществ. Максимальное число идентификаторов — 500.
        :param group_id: идентификатор или короткое имя сообщества.
        :param fields: список дополнительных полей, которые необходимо вернуть. Например: city, country, place,
            description, wiki_page, market, members_count, counters, start_date, finish_date, can_post,
            can_see_all_posts, activity, status, contacts, links, fixed_post, verified, site, ban_info, cover. Полный
            список полей доступен на этой странице.  Обратите внимание, для получения некоторых полей требуется право
            доступа groups. Подробнее см. описание полей объекта group

        :return: После успешного выполнения возвращает массив объектов, описывающих сообщества
        """

        params = locals()
        method_name = self._base_method + 'getById'
        return self._call(method_name, params)

    def getCallbackConfirmationCode(self, group_id: str = None) -> dict:
        """
        Позволяет получить строку, необходимую для подтверждения адреса сервера в Callback API.

        :param group_id: идентификатор сообщества.

        :return: Возвращает строку, которую необходимо использовать в качестве ответа на уведомление с типом
            "confirmation" для подтверждения адреса сервера в Callback API.  Обратите внимание, что код, возвращаемый
            методом, можно использовать только для настройки сервера средствами API. В настройках Вашего сообщества
            на сайте ВКонтакте код будет отличаться
        """

        params = locals()
        method_name = self._base_method + 'getCallbackConfirmationCode'
        return self._call(method_name, params)

    def getCallbackServers(self, group_id: str = None, server_ids: str = None) -> dict:
        """
        Получает информацию о серверах для Callback API в сообществе.

        :param group_id: идентификатор сообщества.
        :param server_ids: идентификаторы серверов, данные о которых нужно получить. По умолчанию возвращаются
            все серверы.

        :return: Возвращает число серверов в поле count (integer) и массив объектов items с данными о серверах.
            Каждый объект массива items содержит поля:   id (integer) — идентификатор сервера;  title (string) —
            название сервера;  creator_id (integer) — идентификатор пользователя, который добавил сервер (может
            содержать 0);  url (string) — URL сервера;  secret_key (string) — секретный ключ;  status (string) —
            статус сервера. Возможные значения:   unconfigured — адрес не задан;  failed — подтвердить адрес не
            удалось;  wait — адрес ожидает подтверждения;  ok — сервер подключен
        """

        params = locals()
        method_name = self._base_method + 'getCallbackServers'
        return self._call(method_name, params)

    def getCallbackSettings(self, group_id: str = None, server_id: str = None) -> dict:
        """
        Позволяет получить настройки уведомлений Callback API для сообщества.

        :param group_id: идентификатор сообщества.
        :param server_id: идентификатор сервера.

        :return: После успешного выполнения возвращает объект, содержащий настройки уведомлений в формате
            «название события» : «статус» (0 — уведомления о событии выключены, 1 — уведомления о событии включены).
            Объект содержит следующие поля:  message_new новое сообщение  integer, [0,1] message_reply новое
            исходящее сообщение   integer, [0,1] message_edit редактирование сообщения   integer, [0,1] message_allow
            новая подписка на сообщения   integer, [0,1] message_deny новый запрет сообщений   integer, [0,1]
            photo_new добавление новой фотографии   integer, [0,1] audio_new добавление новой аудиозаписи   integer,
            [0,1] video_new добавление новой видеозаписи   integer, [0,1] wall_reply_new добавление нового
            комментария на стене   integer, [0,1] wall_reply_edit редактирование комментария на стене   integer,
            [0,1] wall_reply_delete удаление комментария на стене   integer, [0,1] wall_post_new добавление новой
            записи на стене   integer, [0,1] wall_repost новый репост записи на стене   integer, [0,1] board_post_new
            добавление нового комментария в обсуждении   integer, [0,1] board_post_edit редактирование комментария в
            обсуждении   integer, [0,1] board_post_delete удаление комментария в обсуждении   integer, [0,1]
            board_post_restore восстановление комментария в обсуждении   integer, [0,1] photo_comment_new добавление
            нового комментария к фото  integer, [0,1] photo_comment_edit редактирование комментария к фото  integer,
            [0,1] photo_comment_delete удаление комментария к фото  integer, [0,1] photo_comment_restore
            восстановление комментария к фото  integer, [0,1] video_comment_new добавление нового комментария к видео
            integer, [0,1] video_comment_edit редактирование комментария к видео  integer, [0,1] video_comment_delete
            удаление комментария к видео  integer, [0,1] video_comment_restore восстановление комментария к видео
            integer, [0,1] market_comment_new добавление нового комментария к товару  integer, [0,1]
            market_comment_edit редактирование комментария к товару  integer, [0,1] market_comment_delete удаление
            комментария к товару  integer, [0,1] market_comment_restore восстановление удалённого комментария к
            товару  integer, [0,1] poll_vote_new новый голос в публичном опросе  integer, [0,1] group_join вступление
            в сообщество   integer, [0,1] group_leave выход участника из сообщества   integer, [0,1] user_block
            занесение пользователя в черный список   integer, [0,1] user_unblock удаление пользователя из черного
            списка   integer, [0,1] group_change_settings изменение настроек сообщества   integer, [0,1]
            group_change_photo изменение главной фотографии   integer, [0,1] group_officers_edit изменение
            руководства сообщества   integer, [0,1
        """

        params = locals()
        method_name = self._base_method + 'getCallbackSettings'
        return self._call(method_name, params)

    def getCatalog(self, category_id: str = None, subcategory_id: str = None) -> dict:
        """
        Возвращает список сообществ выбранной категории каталога.

        :param category_id: идентификатор категории, полученный в методе groups.getCatalogInfo.
        :param subcategory_id: идентификатор подкатегории, полученный в методе groups.getCatalogInfo.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count
            (integer) и массив объектов, описывающих сообщества, в поле items
        """

        params = locals()
        method_name = self._base_method + 'getCatalog'
        return self._call(method_name, params)

    def getCatalogInfo(self, extended: str = None, subcategories: str = None) -> dict:
        """
        Возвращает список категорий для каталога сообществ.

        :param extended: 1 — вернуть информацию о количестве сообществ в категории и три сообщества для
            предпросмотра.  По умолчанию 0.
        :param subcategories: 1 — вернуть информацию об подкатегориях.  По умолчанию 0.

        :return: После успешного выполнения возвращает поле enabled (0 — каталог недоступен для пользователя, 1 —
            каталог доступен), и, если enabled=1, массив categories объектов — категорий товаров.  Объект массива
            categories — категория каталога товаров.  id идентификатор категории.   положительное число name название
            категории.   строка subcategories поле возвращается при использовании subcategories=1. Массив объектов-
            подкатегорий. Каждый из объектов содержит поля id и name, содержащие идентификатор и название
            подкатегории.  Дополнительные поля (extended=1)  page_count количество сообществ в категории.
            положительное число page_previews массив объектов сообществ для предпросмотра
        """

        params = locals()
        method_name = self._base_method + 'getCatalogInfo'
        return self._call(method_name, params)

    def getInvitedUsers(self, group_id: str = None, offset: str = None, count: str = None, fields: str = None,
                        name_case: str = None) -> dict:
        """
        Возвращает список пользователей, которые были приглашены в группу.

        :param group_id: идентификатор группы, список приглашенных в которую пользователей нужно вернуть.
        :param offset: смещение, необходимое для выборки определённого подмножества пользователей.
        :param count: количество пользователей, информацию о которых нужно вернуть.
        :param fields: список дополнительных полей, которые необходимо вернуть.  Доступные значения: nickname,
            domain, sex, bdate, city, country, timezone, photo_50, photo_100, photo_200_orig, has_mobile, contacts,
            education, online, relation, last_seen, status, can_write_private_message, can_see_all_posts, can_post,
            universities
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.

        :return: Возвращает список объектов пользователей
        """

        params = locals()
        method_name = self._base_method + 'getInvitedUsers'
        return self._call(method_name, params)

    def getInvites(self, offset: str = None, count: str = None, extended: str = None) -> dict:
        """
        Данный метод возвращает список приглашений в сообщества и встречи текущего пользователя.

        :param offset: смещение, необходимое для выборки определённого подмножества приглашений.
        :param count: количество приглашений, которое необходимо вернуть.
        :param extended: 1 — вернуть дополнительную информацию о пользователях, отправлявших приглашения. По
            умолчанию — 0.

        :return: После успешного выполнения возвращает количество результатов в поле count и массив объектов,
            описывающих сообщества, с дополнительным полем invited_by, содержащим идентификатор пользователя, который
            отправил приглашение, в поле items.  Если был передан параметр extended=1, дополнительно будет возвращен
            список profiles пользователей, отправивших приглашения. Каждый объект в списке содержит поля id,
            first_name, last_name
        """

        params = locals()
        method_name = self._base_method + 'getInvites'
        return self._call(method_name, params)

    def getLongPollServer(self, group_id: str = None) -> dict:
        """
        Возвращает данные для подключения к Bots Longpoll API.

        :param group_id: идентификатор сообщества.

        :return: Возвращает объект, который содержит следующие поля:   key (string) — ключ;  server (string) —
            url сервера;  ts (string) — timestamp
        """

        params = locals()
        method_name = self._base_method + 'getLongPollServer'
        return self._call(method_name, params)

    def getLongPollSettings(self, group_id: str = None) -> dict:
        """
        Получает настройки Bots Longpoll API для сообщества.

        :param group_id: идентификатор сообщества.

        :return: Возвращает объект, который содержит следующие поля:   is_enabled (boolean) — true, если Bots
            Longpoll включен в сообществе.  events (object) — настройки Bots Longpoll. объект, содержащий настройки
            уведомлений в формате «название события» : «статус» (0 — уведомления о событии выключены, 1 — уведомления
            о событии включены). Объект содержит следующие поля:   message_new новое сообщение  integer, [0,1]
            message_reply новое исходящее сообщение   integer, [0,1] message_allow новая подписка на сообщения
            integer, [0,1] message_deny новый запрет сообщений   integer, [0,1] photo_new добавление новой фотографии
            integer, [0,1] audio_new добавление новой аудиозаписи   integer, [0,1] video_new добавление новой
            видеозаписи   integer, [0,1] wall_reply_new добавление нового комментария на стене   integer, [0,1]
            wall_reply_edit редактирование комментария на стене   integer, [0,1] wall_reply_delete удаление
            комментария на стене   integer, [0,1] wall_post_new добавление новой записи на стене   integer, [0,1]
            wall_repost новый репост записи на стене   integer, [0,1] board_post_new добавление нового комментария в
            обсуждении   integer, [0,1] board_post_edit редактирование комментария в обсуждении   integer, [0,1]
            board_post_delete удаление комментария в обсуждении   integer, [0,1] board_post_restore восстановление
            комментария в обсуждении   integer, [0,1] photo_comment_new добавление нового комментария к фото
            integer, [0,1] photo_comment_edit редактирование комментария к фото  integer, [0,1] photo_comment_delete
            удаление комментария к фото  integer, [0,1] photo_comment_restore восстановление комментария к фото
            integer, [0,1] video_comment_new добавление нового комментария к видео  integer, [0,1] video_comment_edit
            редактирование комментария к видео  integer, [0,1] video_comment_delete удаление комментария к видео
            integer, [0,1] video_comment_restore восстановление комментария к видео  integer, [0,1]
            market_comment_new добавление нового комментария к товару  integer, [0,1] market_comment_edit
            редактирование комментария к товару  integer, [0,1] market_comment_delete удаление комментария к товару
            integer, [0,1] market_comment_restore восстановление удалённого комментария к товару  integer, [0,1]
            poll_vote_new новый голос в публичном опросе  integer, [0,1] group_join вступление в сообщество
            integer, [0,1] group_leave выход участника из сообщества   integer, [0,1] user_block занесение
            пользователя в черный список   integer, [0,1] user_unblock удаление пользователя из черного списка
            integer, [0,1] group_change_settings изменение настроек сообщества   integer, [0,1] group_change_photo
            изменение главной фотографии   integer, [0,1] group_officers_edit изменение руководства сообщества
            integer, [0,1
        """

        params = locals()
        method_name = self._base_method + 'getLongPollSettings'
        return self._call(method_name, params)

    def getMembers(self, group_id: str = None, sort: str = None, offset: str = None, count: str = None,
                   fields: str = None, filter: str = None) -> dict:
        """
        Возвращает список участников сообщества.

        :param group_id: идентификатор или короткое имя сообщества.
        :param sort: сортировка, с которой необходимо вернуть список участников. Может принимать значения:
            id_asc — в порядке возрастания id;  id_desc — в порядке убывания id;  time_asc — в хронологическом
            порядке по вступлению в сообщество;  time_desc — в антихронологическом порядке по вступлению в
            сообщество.  Сортировка по time_asc и time_desc возможна только при вызове от модератора сообщества.
        :param offset: смещение, необходимое для выборки определенного подмножества участников. По умолчанию 0.
        :param count: количество участников сообщества, информацию о которых необходимо получить.
        :param fields: список дополнительных полей, которые необходимо вернуть.  Доступные значения: sex, bdate,
            city, country, photo_50, photo_100, photo_200_orig, photo_200, photo_400_orig, photo_max, photo_max_orig,
            online, online_mobile, lists, domain, has_mobile, contacts, connections, site, education, universities,
            schools, can_post, can_see_all_posts, can_see_audio, can_write_private_message, status, last_seen,
            common_count, relation, relatives
        :param filter:   friends — будут возвращены только друзья в этом сообществе.  unsure — будут возвращены
            пользователи, которые выбрали «Возможно пойду» (если сообщество относится к мероприятиям).  managers —
            будут возвращены только руководители сообщества (доступно при запросе с передачей access_token от имени
            администратора сообщества).

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count
            (integer) и массив идентификаторов пользователей в поле items ([integer]).  Если был передан параметр
            filter=managers, возвращается дополнительное поле role (string), которое содержит уровень полномочий
            руководителя:   moderator — модератор;  editor — редактор;  administrator — администратор;  creator —
            создатель сообщества
        """

        params = locals()
        method_name = self._base_method + 'getMembers'
        return self._call(method_name, params)

    def getOnlineStatus(self, group_id: str = None) -> dict:
        """
        Получает информацию о статусе «онлайн» в сообществе.

        :param group_id: идентификатор сообщества.

        :return: Возвращает объект, который содержит поля:   status — статус сообщества. Возможные значения:
            none — сообщество не онлайн;  online — сообщество онлайн (отвечает мгновенно);  answer_mark — сообщество
            отвечает быстро.   minutes — оценка времени ответа в минутах (для status = answer_mark)
        """

        params = locals()
        method_name = self._base_method + 'getOnlineStatus'
        return self._call(method_name, params)

    def getRequests(self, group_id: str = None, offset: str = None, count: str = None, fields: str = None) -> dict:
        """
        Возвращает список заявок на вступление в сообщество.

        :param group_id: идентификатор сообщества (указывается без знака «минус»).
        :param offset: смещение, необходимое для выборки определенного подмножества результатов. По умолчанию —
            0.
        :param count: число результатов, которые необходимо вернуть.
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.
            Доступные значения: sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200,
            photo_400_orig, photo_max, photo_max_orig, online, online_mobile, domain, has_mobile, contacts,
            connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio,
            can_write_private_message, status, last_seen, common_count, relation, relatives, counters, screen_name,
            maiden_name, timezone, occupation,activities, interests, music, movies, tv, books, games, about, quotes

        :return: Возвращает список идентификаторов пользователей, отправивших заявки на вступление в сообщество.
            Если было передано значение в параметре fields, возвращается список объектов пользователей
        """

        params = locals()
        method_name = self._base_method + 'getRequests'
        return self._call(method_name, params)

    def getSettings(self, group_id: str = None) -> dict:
        """
        Позволяет получать данные, необходимые для отображения страницы редактирования данных сообщества.

        :param group_id: идентификатор сообщества, данные которого необходимо получить.

        :return: В случае успешного выполнения метод вернет объект, содержащий данные сообщества, которые
            позволят отобразить форму редактирования для метода groups.edit.  В ответе содержится объект с полями:
            title  stringназвание сообщества. description  stringописание сообщества. address  stringкороткий адрес.
            wall  integerнастройки стены. photos  integerнастройки фотографий. video  integerнастройки видеозаписей.
            audio  integerнастройки аудиозаписей. docs  integerнастройки документов. topics  integerнастройки
            обсуждений. wiki  integerнастройки вики-страниц. messages  integerсообщения сообщества. Возможные
            значения:   1 — включены;  0 — выключены. obscene_filter integerнастройки фильтра нецензурных слов.
            obscene_stopwords integerнастройки фильтра комментариев по ключевым словам. obscene_words stringсписок
            стоп-слов. public_category  integerкатегория публичной страницы. public_subcategory  integerподкатегория
            публичной страницы. public_category_list  arrayсписок возможных категорий для публичных страниц. access
            integerтип сообщества. subject  integerидентификатор тематики. subject_list  arrayсписок возможных
            тематик. Массив объектов, каждый из которых содержит поля:   id (integer) — идентификатор тематики;  name
            (string) — название тематики. rss  stringадрес RSS-ленты. website  stringадрес веб-сайта. age_limits
            integerвозрастные ограничения market  objectнастройки блока товаров. Объект, содержащий поля:   enabled
            (integer) — включен ли блок товаров (1 или 0);  comments_enabled (integer) — включены ли комментарии к
            товарам (1 или 0);  country_ids (array) — идентификаторы стран;  city_ids (array) — идентификаторы
            городов;  contact_id (integer) — идентификатор контактного лица;  currency (object) — объект, описывающий
            валюту
        """

        params = locals()
        method_name = self._base_method + 'getSettings'
        return self._call(method_name, params)

    def getTagList(self, group_id: str = None) -> dict:
        """
        Возвращает список тегов сообщества

        :param group_id: Идентификатор сообщества

        :return
        """

        params = locals()
        method_name = self._base_method + 'getTagList'
        return self._call(method_name, params)

    def getTokenPermissions(self) -> dict:
        """
        Возвращает настройки прав для ключа доступа сообщества.

        :return: Возвращает объект, который содержит поля:   mask (integer) — битовая маска ключа доступа;
            settings (array) — массив объектов, описывающих права доступа. Каждый объект в массиве содержит поля:
            setting (integer) — битовая маска права доступа;  name (string) — название права доступа
        """

        params = locals()
        method_name = self._base_method + 'getTokenPermissions'
        return self._call(method_name, params)

    def invite(self, group_id: str = None, user_id: str = None) -> dict:
        """
        Позволяет приглашать друзей в группу.

        :param group_id: идентификатор группы, в которую необходимо выслать приглашение
        :param user_id: идентификатор пользователя, которому необходимо выслать приглашение

        :return: В случае успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'invite'
        return self._call(method_name, params)

    def isMember(self, group_id: str = None, user_id: str = None, user_ids: str = None, extended: str = None) -> dict:
        """
        Возвращает информацию о том, является ли пользователь участником сообщества.

        :param group_id: идентификатор или короткое имя сообщества.
        :param user_id: идентификатор пользователя.
        :param user_ids: идентификаторы пользователей, не более 500.
        :param extended: 1 — вернуть ответ в расширенной форме. По умолчанию — 0.

        :return: Возвращает 1 в случае, если пользователь с идентификатором user_id является участником
            сообщества с идентификатором group_id, иначе 0.   При использовании параметра extended Возвращает объект,
            который содержит поля:   member (integer, [0,1]) — является ли пользователь участником сообщества;  и
            может содержать поля:   request (integer, [0,1]) — есть ли непринятая заявка от пользователя на
            вступление в группу (такую заявку можно отозвать методом groups.leave);  invitation (integer, [0,1]) —
            приглашён ли пользователь в группу или встречу;  can_invite (integer, [0,1]) — может ли автор запроса
            приглашать пользователя в группу;  can_recall (integer, [0,1]) — может ли автор отменить приглашение.
            Появляется, если invitation: 1.    При передаче нескольких идентификаторов Возвращает результат в виде
            массива объектов, в которых есть поля user_id (integer) и member (integer, [0,1])
        """

        params = locals()
        method_name = self._base_method + 'isMember'
        return self._call(method_name, params)

    def join(self, group_id: str = None, not_sure: str = None) -> dict:
        """
        Данный метод позволяет вступить в группу, публичную страницу, а также подтвердить участие во встрече.

        :param group_id: идентификатор сообщества.
        :param not_sure: опциональный параметр, учитываемый, если group_id принадлежит встрече. 1 — Возможно
            пойду. 0 — Точно пойду. По умолчанию 0.

        :return: В случае успешного вступления метод вернёт 1
        """

        params = locals()
        method_name = self._base_method + 'join'
        return self._call(method_name, params)

    def leave(self, group_id: str = None) -> dict:
        """
        Позволяет покинуть сообщество или отклонить приглашение в сообщество.

        :param group_id: идентификатор сообщества.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'leave'
        return self._call(method_name, params)

    def removeUser(self, group_id: str = None, user_id: str = None) -> dict:
        """
        Позволяет исключить пользователя из группы или отклонить заявку на вступление.

        :param group_id: идентификатор группы, из которой необходимо исключить пользователя.
        :param user_id: идентификатор пользователя, которого нужно исключить.

        :return: В случае успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'removeUser'
        return self._call(method_name, params)

    def reorderLink(self, group_id: str = None, link_id: str = None, after: str = None) -> dict:
        """
        Позволяет менять местоположение ссылки в списке.

        :param group_id: идентификатор группы, внутри которой перемещается ссылка
        :param link_id: идентификатор ссылки, которую необходимо переместить
        :param after: идентификатор ссылки после которой необходимо разместить перемещаемую ссылку. 0 – если
            ссылку нужно разместить в начале списка.

        :return: В случае успешного выполнение метод возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'reorderLink'
        return self._call(method_name, params)

    def search(self, q: str = None, type: str = None, country_id: str = None, city_id: str = None, future: str = None,
               market: str = None, sort: str = None, offset: str = None, count: str = None) -> dict:
        """
        Осуществляет поиск сообществ по заданной подстроке.

        :param q: текст поискового запроса.
        :param type: тип сообщества. Возможные значения: group, page, event.
        :param country_id: идентификатор страны.
        :param city_id: идентификатор города. При передаче этого параметра поле country_id игнорируется.
        :param future: при передаче значения 1 будут выведены предстоящие события. Учитывается только при
            передаче в качестве type значения event.
        :param market: при передаче значения 1 будут выведены сообщества с включенными товарами.
        :param sort:   0 — сортировать по умолчанию (аналогично результатам поиска в полной версии сайта);  1 —
            сортировать по скорости роста;  2 — сортировать по отношению дневной посещаемости к количеству
            пользователей;  3 — сортировать по отношению количества лайков к количеству пользователей;  4 —
            сортировать по отношению количества комментариев к количеству пользователей;  5 — сортировать по
            отношению количества записей в обсуждениях к количеству пользователей.
        :param offset: смещение, необходимое для выборки определённого подмножества результатов поиска. По
            умолчанию — 0.
        :param count: количество результатов поиска, которое необходимо вернуть. Обратите внимание — даже при
            использовании параметра offset для получения информации доступны только первые 1000 результатов.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count
            (integer) и массив объектов group в поле items
        """

        params = locals()
        method_name = self._base_method + 'search'
        return self._call(method_name, params)

    def setCallbackSettings(self, group_id: str = None, server_id: str = None, api_version: str = None,
                            message_new: str = None, message_reply: str = None, message_allow: str = None,
                            message_edit: str = None, message_deny: str = None, message_typing_state: str = None,
                            photo_new: str = None, audio_new: str = None, video_new: str = None,
                            wall_reply_new: str = None, wall_reply_edit: str = None, wall_reply_delete: str = None,
                            wall_reply_restore: str = None, wall_post_new: str = None, wall_repost: str = None,
                            board_post_new: str = None, board_post_edit: str = None, board_post_restore: str = None,
                            board_post_delete: str = None, photo_comment_new: str = None,
                            photo_comment_edit: str = None, photo_comment_delete: str = None,
                            photo_comment_restore: str = None, video_comment_new: str = None,
                            video_comment_edit: str = None, video_comment_delete: str = None,
                            video_comment_restore: str = None, market_comment_new: str = None,
                            market_comment_edit: str = None, market_comment_delete: str = None,
                            market_comment_restore: str = None, poll_vote_new: str = None, group_join: str = None,
                            group_leave: str = None, group_change_settings: str = None, group_change_photo: str = None,
                            group_officers_edit: str = None, user_block: str = None, user_unblock: str = None,
                            lead_forms_new: str = None) -> dict:
        """
        Позволяет задать настройки уведомлений о событиях в Callback API.

        :param group_id: идентификатор сообщества.
        :param server_id: идентификатор сервера.
        :param api_version: версия Callback API
        :param message_new: уведомления о новых сообщениях (0 — выключить, 1 — включить).
        :param message_reply: уведомления об исходящем сообщении (0 — выключить, 1 — включить).
        :param message_allow: уведомления о подписке на сообщения (0 — выключить, 1 — включить).
        :param message_edit: уведомления о редактировании сообщения (0 — выключить, 1 — включить).
        :param message_deny: уведомления о запрете на сообщения (0 — выключить, 1 — включить).
        :param message_typing_state: уведомления о наборе текста сообщения ('0 — выключить, 1'' — включить).
        :param photo_new: уведомления о добавлении новой фотографии (0 — выключить, 1 — включить).
        :param audio_new: уведомления о добавлении новой аудиозаписи (0 — выключить, 1 — включить).
        :param video_new: уведомления о добавлении новой видеозаписи (0 — выключить, 1 — включить).
        :param wall_reply_new: уведомления о добавлении нового комментария на стене (0 — выключить, 1 —
            включить).
        :param wall_reply_edit: уведомления о редактировании комментария на стене (0 — выключить, 1 — включить).
        :param wall_reply_delete: уведомления об удалении комментария на стене (0 — выключить, 1 — включить).
        :param wall_reply_restore: уведомления о восстановлении комментария на стене (0 — выключить, 1 —
            включить).
        :param wall_post_new: уведомления о новой записи на стене (0 — выключить, 1 — включить).
        :param wall_repost: уведомления о репосте записи (0 — выключить, 1 — включить).
        :param board_post_new: уведомления о создании комментария в обсуждении (0 — выключить, 1 — включить).
        :param board_post_edit: уведомления о редактировании комментария в обсуждении (0 — выключить, 1 —
            включить).
        :param board_post_restore: уведомление о восстановлении комментария в обсуждении (0 — выключить, 1 —
            включить).
        :param board_post_delete: уведомления об удалении комментария в обсуждении (0 — выключить, 1 — включить).
        :param photo_comment_new: уведомления о добавлении нового комментария к фото (0 — выключить, 1 —
            включить).
        :param photo_comment_edit: уведомления о редактировании комментария к фото (0 — выключить, 1 — включить).
        :param photo_comment_delete: уведомления об удалении комментария к фото (0 — выключить, 1 — включить).
        :param photo_comment_restore: уведомления о восстановлении комментария к фото (0 — выключить, 1 —
            включить).
        :param video_comment_new: уведомления о добавлении нового комментария к видео (0 — выключить, 1 —
            включить).
        :param video_comment_edit: уведомления о редактировании комментария к видео (0 — выключить, 1 —
            включить).
        :param video_comment_delete: уведомления об удалении комментария к видео (0 — выключить, 1 — включить).
        :param video_comment_restore: уведомления о восстановлении комментария к видео (0 — выключить, 1 —
            включить).
        :param market_comment_new: уведомления о добавлении нового комментария к товару (0 — выключить, 1 —
            включить).
        :param market_comment_edit: уведомления о редактировании комментария к товару (0 — выключить, 1 —
            включить).
        :param market_comment_delete: уведомления об удалении комментария к товару (0 — выключить, 1 — включить).
        :param market_comment_restore: уведомления о восстановлении комментария к товару (0 — выключить, 1 —
            включить).
        :param poll_vote_new: уведомления о новом голосе в публичных опросах (0 — выключить, 1 — включить).
        :param group_join: уведомления о вступлении в сообщество (0 — выключить, 1 — включить).
        :param group_leave: уведомления о выходе из сообщества (0 — выключить, 1 — включить).
        :param group_change_settings: уведомления об изменении настроек (0 — выключить, 1 — включить).
        :param group_change_photo: уведомления об изменении главной фотографии (0 — выключить, 1 — включить).
        :param group_officers_edit: уведомления об изменении руководства (0 — выключить, 1 — включить).
        :param user_block: уведомления об внесении пользователя в чёрный список (0 — выключить, 1 — включить).
        :param user_unblock: уведомления об исключении пользователя из чёрного списка (0 — выключить, 1 —
            включить).
        :param lead_forms_new: уведомления о заполнении формы

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setCallbackSettings'
        return self._call(method_name, params)

    def setLongPollSettings(self, group_id: str = None, enabled: str = None, api_version: str = None,
                            message_new: str = None, message_reply: str = None, message_allow: str = None,
                            message_deny: str = None, message_edit: str = None, message_typing_state: str = None,
                            photo_new: str = None, audio_new: str = None, video_new: str = None,
                            wall_reply_new: str = None, wall_reply_edit: str = None, wall_reply_delete: str = None,
                            wall_reply_restore: str = None, wall_post_new: str = None, wall_repost: str = None,
                            board_post_new: str = None, board_post_edit: str = None, board_post_restore: str = None,
                            board_post_delete: str = None, photo_comment_new: str = None,
                            photo_comment_edit: str = None, photo_comment_delete: str = None,
                            photo_comment_restore: str = None, video_comment_new: str = None,
                            video_comment_edit: str = None, video_comment_delete: str = None,
                            video_comment_restore: str = None, market_comment_new: str = None,
                            market_comment_edit: str = None, market_comment_delete: str = None,
                            market_comment_restore: str = None, poll_vote_new: str = None, group_join: str = None,
                            group_leave: str = None, group_change_settings: str = None, group_change_photo: str = None,
                            group_officers_edit: str = None, user_block: str = None, user_unblock: str = None) -> dict:
        """
        Задаёт настройки для Bots Long Poll API в сообществе.

        :param group_id: идентификатор сообщества.
        :param enabled: 1 — включить Bots Long Poll, 0 — отключить.
        :param api_version: версия API
        :param message_new: уведомления о новых сообщениях (0 — выключить, 1 — включить).
        :param message_reply: уведомления об исходящем сообщении (0 — выключить, 1 — включить).
        :param message_allow: уведомления о подписке на сообщения (0 — выключить, 1 — включить).
        :param message_deny: уведомления о запрете на сообщения (0 — выключить, 1 — включить).
        :param message_edit: уведомления о редактировании сообщения (0 — выключить, 1 — включить).
        :param message_typing_state:
        :param photo_new: уведомления о добавлении новой фотографии (0 — выключить, 1 — включить).
        :param audio_new: уведомления о добавлении новой аудиозаписи (0 — выключить, 1 — включить).
        :param video_new: уведомления о добавлении новой видеозаписи (0 — выключить, 1 — включить).
        :param wall_reply_new: уведомления о добавлении нового комментария на стене (0 — выключить, 1 —
            включить).
        :param wall_reply_edit: уведомления о редактировании комментария на стене (0 — выключить, 1 — включить).
        :param wall_reply_delete: уведомления об удалении комментария на стене (0 — выключить, 1 — включить).
        :param wall_reply_restore: уведомления о восстановлении комментария на стене (0 — выключить, 1 —
            включить).
        :param wall_post_new: уведомления о новой записи на стене (0 — выключить, 1 — включить).
        :param wall_repost: уведомления о репосте записи (0 — выключить, 1 — включить).
        :param board_post_new: уведомления о создании комментария в обсуждении (0 — выключить, 1 — включить).
        :param board_post_edit: уведомления о редактировании комментария в обсуждении (0 — выключить, 1 —
            включить).
        :param board_post_restore: уведомление о восстановлении комментария в обсуждении (0 — выключить, 1 —
            включить).
        :param board_post_delete: уведомления об удалении комментария в обсуждении (0 — выключить, 1 — включить).
        :param photo_comment_new: уведомления о добавлении нового комментария к фото (0 — выключить, 1 —
            включить).
        :param photo_comment_edit: уведомления о редактировании комментария к фото (0 — выключить, 1 — включить).
        :param photo_comment_delete: уведомления об удалении комментария к фото (0 — выключить, 1 — включить).
        :param photo_comment_restore: уведомления о восстановлении комментария к фото (0 — выключить, 1 —
            включить).
        :param video_comment_new: уведомления о добавлении нового комментария к видео (0 — выключить, 1 —
            включить).
        :param video_comment_edit: уведомления о редактировании комментария к видео (0 — выключить, 1 —
            включить).
        :param video_comment_delete: уведомления об удалении комментария к видео (0 — выключить, 1 — включить).
        :param video_comment_restore: уведомления о восстановлении комментария к видео (0 — выключить, 1 —
            включить).
        :param market_comment_new: уведомления о добавлении нового комментария к товару (0 — выключить, 1 —
            включить).
        :param market_comment_edit: уведомления о редактировании комментария к товару (0 — выключить, 1 —
            включить).
        :param market_comment_delete: уведомления об удалении комментария к товару (0 — выключить, 1 — включить).
        :param market_comment_restore: уведомления о восстановлении комментария к товару (0 — выключить, 1 —
            включить).
        :param poll_vote_new: уведомления о новом голосе в публичных опросах (0 — выключить, 1 — включить).
        :param group_join: уведомления о вступлении в сообщество (0 — выключить, 1 — включить).
        :param group_leave: уведомления о выходе из сообщества (0 — выключить, 1 — включить).
        :param group_change_settings: уведомления об изменении настроек (0 — выключить, 1 — включить).
        :param group_change_photo: уведомления об изменении главной фотографии (0 — выключить, 1 — включить).
        :param group_officers_edit: уведомления об изменении руководства (0 — выключить, 1 — включить).
        :param user_block: уведомления об внесении пользователя в чёрный список (0 — выключить, 1 — включить).
        :param user_unblock: уведомления об исключении пользователя из чёрного списка (0 — выключить, 1 —
            включить).

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setLongPollSettings'
        return self._call(method_name, params)

    def setSettings(self, group_id: str = None, messages: str = None, bots_capabilities: str = None,
                    bots_start_button: str = None, bots_add_to_chat: str = None) -> dict:
        """
        Устанавливает настройки сообщества

        :param group_id: идентификатор сообщества.
        :param messages: сообщения сообщества. Возможные значения:   0 — выключены;  1 — включены.
        :param bots_capabilities: возможности ботов (использование клавиатуры, добавление в беседу). Возможные
            значения:   0 — выключены;  1 — включены.
        :param bots_start_button: кнопка «Начать» в диалоге с сообществом.  Работает, в случае если
            bots_capabilities=1.  Если эта настройка включена, то при заходе в беседу с Вашим сообществом в первый
            раз пользователь увидит кнопку с командой «Начать», которая отправляет команду start. Payload этого
            сообщения будет выглядеть так: {"command":"start"}    Возможные значения:   0 — выключена;  1 — включена.
        :param bots_add_to_chat: добавление бота в беседы.  Работает, в случае если bots_capabilities=1.
            Возможные значения:   0 — запрещено;  1 — разрешено.

        :return: В случае успеха возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setSettings'
        return self._call(method_name, params)

    def tagAdd(self, group_id: str = None, tag_name: str = None, tag_color: str = None) -> dict:
        """
        Позволяет добавить новый тег в сообщество

        :param group_id: Идентификатор сообщества
        :param tag_name: Имя тега
        :param tag_color: Цвет тега. Разрешается использовать следующие цвета: 4bb34b, 5c9ce6, e64646, 792ec0,
            63b9ba, ffa000, ffc107, 76787a, 9e8d6b, 45678f, 539b9c, 454647, 7a6c4f, 6bc76b, 5181b8, ff5c5c, a162de,
            7ececf, aaaeb3, bbaa84

        :return
        """

        params = locals()
        method_name = self._base_method + 'tagAdd'
        return self._call(method_name, params)

    def tagBind(self, group_id: str = None, tag_id: str = None, user_id: str = None, act: str = None) -> dict:
        """
        Позволяет "привязывать" и "отвязывать" теги сообщества к беседам.

        :param group_id: Идентификатор группы
        :param tag_id: Идентификатор тега
        :param user_id:
        :param act: Действие с тегом   "bind" -  привязать  "unbind" - отвязать

        :return
        """

        params = locals()
        method_name = self._base_method + 'tagBind'
        return self._call(method_name, params)

    def tagDelete(self, group_id: str = None, tag_id: str = None) -> dict:
        """
        Позволяет удалить тег сообщества

        :param group_id: Идентификатор группы
        :param tag_id: Идентификатор удаляемого тега

        :return
        """

        params = locals()
        method_name = self._base_method + 'tagDelete'
        return self._call(method_name, params)

    def tagUpdate(self, group_id: str = None, tag_id: str = None, tag_name: str = None, tag_color: str = None) -> dict:
        """
        Позволяет изменить существующий тег

        :param group_id: Идентификатор сообщества
        :param tag_id: Идентификатор тега
        :param tag_name: Имя тега
        :param tag_color: Цвет тега. Разрешается использовать следующие цвета: 4bb34b, 5c9ce6, e64646, 792ec0,
            63b9ba, ffa000, ffc107, 76787a, 9e8d6b, 45678f, 539b9c, 454647, 7a6c4f, 6bc76b, 5181b8, ff5c5c, a162de,
            7ececf, aaaeb3, bbaa84

        :return
        """

        params = locals()
        method_name = self._base_method + 'tagUpdate'
        return self._call(method_name, params)

    def unban(self, group_id: str = None, owner_id: str = None) -> dict:
        """
        Убирает пользователя или группу из черного списка сообщества.

        :param group_id: идентификатор сообщества.
        :param owner_id: идентификатор пользователя или группы, которого нужно убрать из черного списка.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'unban'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Secure(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Secure, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'secure.'

    def addAppEvent(self, user_id: str = None, activity_id: str = None, value: str = None) -> dict:
        """
        Добавляет информацию о достижениях пользователя в приложении.

        :param user_id: идентификатор пользователя, для которого нужно записать данные.
        :param activity_id: идентификатор достижения. Доступные значения:   1 — достигнут новый уровень, работает
            аналогично secure.setUserLevel;  2 — заработано новое число очков;  положительное число, отличное от 1 и
            2 — выполнена миссия с идентификатором activity_id.
        :param value: номер уровня или заработанное количество очков (соответственно, для activity_id=1 и
            activity_id=2).  Параметр игнорируется при значении activity_id, отличном от 1 и 2.  Если activity_id =
            1, то максимальное value 15000.  Если activity_id = 2, то максимальное value 10000000.

        :return
        """

        params = locals()
        method_name = self._base_method + 'addAppEvent'
        return self._call(method_name, params)

    def checkToken(self, token: str = None, ip: str = None) -> dict:
        """
        Позволяет проверять валидность пользователя в IFrame, VK Apps и Standalone-приложениях с помощью передаваемого
        в приложения параметра access_token.

        :param token: клиентский access_token
        :param ip: ip адрес пользователя. Обратите внимание, что пользователь может обращаться через ipv6, в этом
            случае обязательно передавать ipv6 адрес пользователя.  Если параметр не передан – ip адрес проверен не
            будет.

        :return: В случае успеха будет возвращен объект, содержащий следующие поля:   success = 1  user_id =
            идентификатор пользователя  date = unixtime дата, когда access_token был сгенерирован  expire = unixtime
            дата, когда access_token станет не валиде
        """

        params = locals()
        method_name = self._base_method + 'checkToken'
        return self._call(method_name, params)

    def getAppBalance(self) -> dict:
        """
        Возвращает платежный баланс (счет) приложения в сотых долях голоса.

        :return: Возвращает количество голосов (в сотых долях), которые есть на счете приложения.  Например, если
            метод возвращает 5000, это означает, что на балансе приложения 50 голосов
        """

        params = locals()
        method_name = self._base_method + 'getAppBalance'
        return self._call(method_name, params)

    def getSMSHistory(self, user_id: str = None, date_from: str = None, date_to: str = None, limit: str = None) -> dict:
        """
        Выводит список SMS-уведомлений, отосланных приложением с помощью метода secure.sendSMSNotification.

        :param user_id: фильтр по id пользователя, которому высылалось уведомление.
        :param date_from: фильтр по дате начала. Задается в виде UNIX-time.
        :param date_to: фильтр по дате окончания. Задается в виде UNIX-time.
        :param limit: количество возвращаемых записей. По умолчанию 1000.

        :return: Возвращает список SMS-уведомлений, отосланных приложением, отсортированных по убыванию даты и
            отфильтрованных с помощью параметров uid, date_from, date_to, limit
        """

        params = locals()
        method_name = self._base_method + 'getSMSHistory'
        return self._call(method_name, params)

    def getTransactionsHistory(self) -> dict:
        """
        Выводит историю транзакций по переводу голосов между пользователями и приложением.

        :return: Возвращает список транзакций, отсортированных по убыванию даты, и отфильтрованных с помощью
            параметров type, uid_from, uid_to, date_from, date_to, limit
        """

        params = locals()
        method_name = self._base_method + 'getTransactionsHistory'
        return self._call(method_name, params)

    def getUserLevel(self, user_ids: str = None) -> dict:
        """
        Возвращает ранее выставленный игровой уровень одного или нескольких пользователей в приложении.

        :param user_ids: идентификаторы пользователей, информацию об уровнях которых требуется получить.

        :return: Возвращает значения игровых уровней пользователей в приложении
        """

        params = locals()
        method_name = self._base_method + 'getUserLevel'
        return self._call(method_name, params)

    def giveEventSticker(self, user_ids: str = None, achievement_id: str = None) -> dict:
        """
        Выдает пользователю стикер и открывает игровое достижение.

        :param user_ids: список id пользователей которым нужно открыть достижение
        :param achievement_id: id игрового достижения на платформе игр

        :return: Возвращает список результатов выполнения в виде списка объектов:  {    "user_id": int,
              "status": string  }  status может принимать значения:  OK - операция успешна
            ERROR_ACHIEVEMENT_ALREADY_OPENED - стикер уже выдан пользователю  ERROR_UNKNOWN_ERROR - непредвиденная
            ошибк
        """

        params = locals()
        method_name = self._base_method + 'giveEventSticker'
        return self._call(method_name, params)

    def sendNotification(self, user_ids: str = None, user_id: str = None, message: str = None) -> dict:
        """
        Отправляет уведомление пользователю.

        :param user_ids: перечисленные через запятую идентификаторы пользователей, которым отправляется
            уведомление (максимум 100 штук).
        :param user_id: идентификатор пользователя.
        :param message: текст уведомления, который следует передавать в кодировке UTF-8 (максимум 254 символа).

        :return: Возвращает перечисленные через запятую ID пользователей, которым было успешно отправлено
            уведомление.  Обратите внимание, нельзя отправлять пользователю более 1 уведомления в час (3 в сутки).
            Кроме того, нельзя отправить одному пользователю два уведомления с одинаковым текстом подряд
        """

        params = locals()
        method_name = self._base_method + 'sendNotification'
        return self._call(method_name, params)

    def sendSMSNotification(self, user_id: str = None, message: str = None) -> dict:
        """
        Отправляет SMS-уведомление на мобильный телефон пользователя.

        :param user_id: id пользователя, которому отправляется SMS-уведомление. Пользователь должен разрешить
            приложению отсылать ему уведомления (getUserSettings, +1).
        :param message: текст SMS, который следует передавать в кодировке UTF-8. Допускаются только латинские
            буквы и цифры. Максимальный размер - 160 символов.

        :return: Возвращает 1 в случае успешной отсылки SMS.  Если номер пользователя еще не известен системе, то
            метод вернет ошибку 146 (The mobile number of the user is unknown). Для решения этой проблемы метод
            users.get возвращает поле has_mobile, которое позволяет определить, известен ли номер пользователя.  Если
            номер пользователя неизвестен, но Вы хотели бы иметь возможность высылать ему SMS-уведомления, необходимо
            предложить ему ввести номер мобильного телефона, не отвлекая от приложения
        """

        params = locals()
        method_name = self._base_method + 'sendSMSNotification'
        return self._call(method_name, params)

    def setCounter(self, counters: str = None, user_id: str = None, counter: str = None, increment: str = None) -> dict:
        """
        Устанавливает счетчик, который выводится пользователю жирным шрифтом в левом меню.

        :param counters: позволяет устанавливать счетчики нескольким пользователям за один запрос. Значение
            следует указывать в следующем формате: user_id1:counter1[:increment],user_id2:counter2[:increment],
            пример: 66748:6:1,6492:2. В случае, если указан этот параметр, параметры counter, user_id и increment не
            учитываются. Можно передать не более 200 значений за один запрос.
        :param user_id: идентификатор пользователя.
        :param counter: значение счетчика.
        :param increment: определяет, нужно ли заменить значение счетчика или прибавить новое значение к уже
            имеющемуся. 1 — прибавить counter к старому значению, 0 — заменить счетчик (по умолчанию).

        :return: Возвращает 1 в случае успешной установки счетчика.   Если пользователь не установил приложение в
            левое меню, метод вернет ошибку 148 (Access to the menu of the user denied). Избежать этой ошибки можно с
            помощью метода account.getAppPermissions.  Вы также можете обращаться к этому методу при стандартном
            взаимодействии с клиентской стороны, указывая setCounter вместо secure.setCounter в названии метода. В
            этом случае параметр uid передавать не нужно, счетчик установится для текущего пользователя.   Метод
            setCounter при стандартном, а не защищенном взаимодействии можно использовать для того, чтобы, например,
            сбрасывать счетчик при заходе пользователя в приложение
        """

        params = locals()
        method_name = self._base_method + 'setCounter'
        return self._call(method_name, params)




from ApiMethod import ApiMethod


class PrettyCards(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(PrettyCards, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'prettyCards.'

    def create(self, owner_id: str = None, photo: str = None, title: str = None, link: str = None, price: str = None,
               price_old: str = None, button: str = None) -> dict:
        """
        Создаёт карточку карусели.

        :param owner_id: Идентификатор владельца карточки. Необходимо указать идентификатор сообщества, взятый со
            знаком минус. Пример: -19542789.
        :param photo: Фотография карточки.  Используйте значение, полученное после загрузки фотографии на сервер.
            См. метод prettyCards.getUploadURL.  Также можно переиспользовать существующую фотографию из другой
            карточки. Используйте значение поля photo, которое возвращает метод prettyCards.get или
            prettyCards.getById.
        :param title: Заголовок
        :param link: Ссылка. Кроме http(s)-ссылок также допускается указание телефонных номеров в виде
            tel:+79111234567
        :param price: Цена. «0» будет отображён как «Бесплатно». Не передавайте этот параметр, чтобы не указывать
            цену.
        :param price_old: Старая цена. Отображается зачёркнутой. «0» будет отображён как «Бесплатно». Не
            передавайте этот параметр, чтобы не указывать старую цену.
        :param button: Кнопка. Не передавайте этот параметр, чтобы не использовать кнопку.  button Текст Действие
            Тип ссылок app_join Запустить Переход по ссылке Приложения и игры app_game_join Играть Переход по ссылке
            Игры open_url Перейти Переход по ссылке Внешние сайты, сообщества, приложения open Открыть Переход по
            ссылке Внешние сайты more Подробнее Переход по ссылке Сообщества call Позвонить Набор номера Телефонные
            номера book Забронировать Набор номера Телефонные номера enroll Записаться Переход по ссылке или набор
            номера Внешние сайты, телефонные номера register Зарегистрироваться Набор номера Телефонные номера buy
            Купить Переход по ссылке Внешние сайты buy_ticket Купить билет Переход по ссылке Внешние сайты to_shop В
            магазин Переход по ссылке Внешние сайты order Заказать Переход по ссылке Внешние сайты create Создать
            Переход по ссылке Внешние сайты install Установить Переход по ссылке Внешние сайты contact Связаться
            Переход по ссылке Внешние сайты fill Заполнить Переход по ссылке Внешние сайты choose Выбрать Переход по
            ссылке Внешние сайты try Попробовать Переход по ссылке Внешние сайты join_public Подписаться Подписка на
            публичную страницу Публичные страницы join_event Я пойду Участие в мероприятии События join_group
            Вступить Вступление в сообщество Сообщества im_group Связаться Переход к диалогу с сообществом
            Сообщества, публичные страницы, события im_group2 Написать Переход к диалогу с сообществом Сообщества,
            публичные страницы, события begin Начать Переход по ссылке Внешние сайты get Получить Переход по ссылке
            Внешние сайты

        :return: Возвращает структуру с информаций о созданной карточке.   owner_id — идентификатор владельца
            карточки  card_id — идентификатор карточк
        """

        params = locals()
        method_name = self._base_method + 'create'
        return self._call(method_name, params)

    def delete(self, owner_id: str = None, card_id: str = None) -> dict:
        """
        Удаляет карточку.

        :param owner_id: Идентификатор владельца карточки.
        :param card_id: Идентификатор карточки.

        :return: Возвращает структуру с информаций об удалённой карточке.   owner_id — идентификатор владельца
            карточки  card_id — идентификатор карточк
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def edit(self, owner_id: str = None, card_id: str = None, photo: str = None, title: str = None, link: str = None,
             price: str = None, price_old: str = None, button: str = None) -> dict:
        """
        Редактирует карточку карусели.

        :param owner_id: Идентификатор владельца карточки.
        :param card_id: Идентификатор карточки.
        :param photo: Новая фотография. Подробнее см. метод prettyCards.create.
        :param title: Новый заголовок.
        :param link: Новая ссылка. Подробнее см. метод prettyCards.create.
        :param price: Новая цена. Подробнее см. метод prettyCards.create.
        :param price_old: Обновлённая старая цена. Подробнее см. метод prettyCards.create.
        :param button: Новая кнопка. Подробнее см. метод prettyCards.create.

        :return: Возвращает структуру с информаций об обновлённой карточке.   owner_id — идентификатор владельца
            карточки  card_id — идентификатор карточк
        """

        params = locals()
        method_name = self._base_method + 'edit'
        return self._call(method_name, params)

    def get(self, owner_id: str = None, offset: str = None, count: str = None) -> dict:
        """
        Возвращает неиспользованные карточки владельца.

        :param owner_id: Идентификатор владельца.
        :param offset: Смещение относительно начала списка карточек.
        :param count: Количество возвращаемых карточек.

        :return: Возвращает массив структур с описанием карточек (подробнее о структуре ответа см. метод
            prettyCards.getById). Возвращаются только те карточки, которые не были прикреплены к рекламной записи
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getById(self, owner_id: str = None, card_ids: str = None) -> dict:
        """
        Возвращает информацию о карточке.

        :param owner_id: Идентификатор владельца карточки.
        :param card_ids: Список идентификаторов карточек, которые необходимо вернуть. Строка с числами,
            разделёнными запятой.

        :return: Возвращает массив структур со следующими полями:   card_id — идентификатор карточки,  link_url —
            целевая ссылка,  title — заголовок,  button — идентификатор кнопки (см. метод prettyCards.create),
            button_text — текст кнопки,  photo — идентификатор фотографии,  images — массив структур с разными
            размерами фотографии:   url — url фотографии,  width — ширина фотографии,  height — высота фотографии,
            price — цена,  price_old — старая цена
        """

        params = locals()
        method_name = self._base_method + 'getById'
        return self._call(method_name, params)

    def getUploadURL(self) -> dict:
        """
        Возвращает URL для загрузки фотографии для карточки.

        :return: Возвращает URL для загрузки фотографии для карточки
        """

        params = locals()
        method_name = self._base_method + 'getUploadURL'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Storage(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Storage, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'storage.'

    def get(self, key: str = None, keys: str = None, user_id: str = None) -> dict:
        """
        Возвращает значение переменной, название которой передано в параметре key.

        :param key: название переменной.
        :param keys: список названий переменных, разделённых запятыми. Если указан этот параметр, то параметр key
            не учитывается.
        :param user_id: id пользователя, переменная которого устанавливается, в случае если данные запрашиваются
            серверным методом.

        :return: Возвращает значение одной или нескольких переменных. Если переменная на сервере отсутствует, то
            будет возвращена пустая строка
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getKeys(self, user_id: str = None, offset: str = None, count: str = None) -> dict:
        """
        Возвращает названия всех переменных.

        :param user_id: id пользователя, названия переменных которого получаются, в случае если данные
            запрашиваются серверным методом.
        :param offset: смещение, необходимое для выборки определенного подмножества названий переменных. По
            умолчанию 0.
        :param count: количество названий переменных, информацию о которых необходимо получить.

        :return: Возвращает массив названий переменных
        """

        params = locals()
        method_name = self._base_method + 'getKeys'
        return self._call(method_name, params)

    def set(self, key: str = None, value: str = None, user_id: str = None) -> dict:
        """
        Сохраняет значение переменной, название которой передано в параметре key.

        :param key: название переменной. Может содержать символы латинского алфавита, цифры, знак тире, нижнее
            подчёркивание [a-zA-Z_\-0-9].
        :param value: значение переменной, сохраняются только первые 4096 байта.
        :param user_id: id пользователя, переменная которого устанавливается, в случае если данные запрашиваются
            серверным методом.

        :return: Возвращает 1 в случае удачного сохранения переменной.  Для удаления переменной необходимо
            передать пустое значение в параметре value
        """

        params = locals()
        method_name = self._base_method + 'set'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Status(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Status, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'status.'

    def get(self, user_id: str = None, group_id: str = None) -> dict:
        """
        Получает текст статуса пользователя или сообщества.

        :param user_id: идентификатор пользователя или сообщества, информацию о статусе которого нужно получить.
        :param group_id: идентификатор сообщества, статус которого необходимо получить.

        :return: В случае успеха возвращает объект, у которого в поле text содержится текст статуса пользователя
            или сообщества.  Если у пользователя включена трансляция играющей музыки в статус и в данный момент
            воспроизводится аудиозапись, то также будет возвращен объект audio
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def set(self, text: str = None, group_id: str = None) -> dict:
        """
        Устанавливает новый статус текущему пользователю или сообществу.

        :param text: текст нового статуса.
        :param group_id: идентификатор сообщества, в котором будет установлен статус. По умолчанию статус
            устанавливается текущему пользователю.

        :return: В случае успешной установки или очистки статуса возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'set'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Likes(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Likes, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'likes.'

    def add(self, type: str = None, owner_id: str = None, item_id: str = None, access_key: str = None) -> dict:
        """
        Добавляет указанный объект в список Мне нравится текущего пользователя.

        :param type: тип объекта.  Возможные типы: post — запись на стене пользователя или группы; comment —
            комментарий к записи на стене; photo — фотография; audio — аудиозапись; video — видеозапись; note —
            заметка; market — товар; photo_comment — комментарий к фотографии; video_comment — комментарий к
            видеозаписи; topic_comment — комментарий в обсуждении; market_comment — комментарий к товару;
        :param owner_id: идентификатор владельца объекта.
        :param item_id: идентификатор объекта.
        :param access_key: ключ доступа в случае работы с приватными объектами.

        :return: В случае успеха возвращает объект с полем likes, в котором находится текущее количество
            пользователей, которые добавили данный объект в свой список Мне нравится
        """

        params = locals()
        method_name = self._base_method + 'add'
        return self._call(method_name, params)

    def delete(self, type: str = None, owner_id: str = None, item_id: str = None, access_key: str = None) -> dict:
        """
        Удаляет указанный объект из списка Мне нравится текущего пользователя

        :param type: тип объекта.  Возможные типы: post — запись на стене пользователя или группы; comment —
            комментарий к записи на стене; photo — фотография; audio — аудиозапись; video — видеозапись; note —
            заметка; photo_comment — комментарий к фотографии; video_comment — комментарий к видеозаписи;
            topic_comment — комментарий в обсуждении; sitepage — страница сайта, на котором установлен виджет «Мне
            нравится».
        :param owner_id: идентификатор владельца объекта.
        :param item_id: идентификатор объекта.
        :param access_key:

        :return: В случае успеха возвращает объект с полем likes, в котором находится текущее количество
            пользователей, которые добавили данный объект в свой список Мне нравится
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def getList(self, type: str = None, owner_id: str = None, item_id: str = None, page_url: str = None,
                filter: str = None, friends_only: str = None, extended: str = None, offset: str = None,
                count: str = None, skip_own: str = None) -> dict:
        """
        Получает список идентификаторов пользователей, которые добавили заданный объект в свой список Мне нравится.

        :param type: тип объекта.  Возможные типы: post — запись на стене пользователя или группы; comment —
            комментарий к записи на стене; photo — фотография; audio — аудиозапись; video — видеозапись; note —
            заметка; market — товар; photo_comment — комментарий к фотографии; video_comment — комментарий к
            видеозаписи; topic_comment — комментарий в обсуждении; market_comment — комментарий к товару; sitepage —
            страница сайта, на котором установлен виджет «Мне нравится».
        :param owner_id: идентификатор владельца Like-объекта: id пользователя, id сообщества (со знаком «минус»)
            или id приложения. Если параметр type равен sitepage, то в качестве owner_id необходимо передавать id
            приложения. Если параметр не задан, то считается, что он равен либо идентификатору текущего пользователя,
            либо идентификатору текущего приложения (если type равен sitepage).
        :param item_id: идентификатор Like-объекта. Если type равен sitepage, то параметр item_id может содержать
            значение параметра page_id, используемый при инициализации виджета «Мне нравится».
        :param page_url: url страницы, на которой установлен виджет «Мне нравится». Используется вместо параметра
            item_id, если при размещении виджета не был указан page_id.
        :param filter: указывает, следует ли вернуть всех пользователей, добавивших объект в список "Мне
            нравится" или только тех, которые рассказали о нем друзьям. Параметр может принимать следующие значения:
            likes — возвращать информацию обо всех пользователях;  copies — возвращать информацию только о
            пользователях, рассказавших об объекте друзьям. По умолчанию возвращается информация обо всех
            пользователях.
        :param friends_only: указывает, необходимо ли возвращать только пользователей, которые являются друзьями
            текущего пользователя. Параметр может принимать следующие значения:   0 — возвращать всех пользователей в
            порядке убывания времени добавления объекта;  1 — возвращать только друзей текущего пользователя в
            порядке убывания времени добавления объекта; Если метод был вызван без авторизации или параметр не был
            задан, то считается, что он равен 0.
        :param extended: 1 — возвращать расширенную информацию о пользователях и сообществах из списка
            поставивших отметку «Мне нравится» или сделавших репост. По умолчанию — 0.
        :param offset: смещение, относительно начала списка, для выборки определенного подмножества. Если
            параметр не задан, то считается, что он равен 0.
        :param count: количество возвращаемых идентификаторов пользователей. Если параметр не задан, то
            считается, что он равен 100, если не задан параметр friends_only, в противном случае 10. Максимальное
            значение параметра 1000, если не задан параметр friends_only, в противном случае 100.
        :param skip_own: не возвращать самого пользователя.

        :return: После успешного выполнения возвращает список идентификаторов пользователей с учетом параметров
            offset и count, которые добавили заданный объект в свой список Мне нравится.  Если параметр type равен
            sitepage, то будет возвращён список пользователей, воспользовавшихся виджетом «Мне нравится» на внешнем
            сайте. Адрес страницы задаётся при помощи параметра page_url или item_id.  Если extended=1, дополнительно
            возвращается массив items, содержащий расширенную информацию о пользователях или сообществах
        """

        params = locals()
        method_name = self._base_method + 'getList'
        return self._call(method_name, params)

    def isLiked(self, user_id: str = None, type: str = None, owner_id: str = None, item_id: str = None) -> dict:
        """
        Проверяет, находится ли объект в списке Мне нравится заданного пользователя.

        :param user_id: идентификатор пользователя, у которого необходимо проверить наличие объекта в списке «Мне
            нравится». Если параметр не задан, то считается, что он равен идентификатору текущего пользователя.
        :param type: тип объекта.  Возможные типы: post — запись на стене пользователя или группы; comment —
            комментарий к записи на стене; photo — фотография; audio — аудиозапись; video — видеозапись; note —
            заметка; photo_comment — комментарий к фотографии; video_comment — комментарий к видеозаписи;
            topic_comment — комментарий в обсуждении;
        :param owner_id: идентификатор владельца Like-объекта. Если параметр не задан, то считается, что он равен
            идентификатору текущего пользователя.  Обратите внимание, идентификатор сообщества в параметре owner_id
            необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору сообщества
            ВКонтакте API (club1)
        :param item_id: идентификатор объекта.

        :return: В случае успеха возвращает объект с полями:   liked — есть ли отметка «Мне нравится» от текущего
            пользователя (0 — отметки нет, 1 — отметка есть);  copied — сделан ли репост текущим пользователем (0 —
            не сделан, 1 — сделан)
        """

        params = locals()
        method_name = self._base_method + 'isLiked'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Database(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Database, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'database.'

    def getChairs(self, faculty_id: str = None, offset: str = None, count: str = None) -> dict:
        """
        Возвращает список кафедр университета по указанному факультету.

        :param faculty_id: идентификатор факультета, кафедры которого необходимо получить.
        :param offset: отступ, необходимый для получения определенного подмножества кафедр.
        :param count: количество кафедр которое необходимо получить.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих кафедры, в поле items.  Каждый объект содержит следующие поля:   id (integer) —
            идентификатор кафедры;  title (string) — название кафедры
        """

        params = locals()
        method_name = self._base_method + 'getChairs'
        return self._call(method_name, params)

    def getCities(self, country_id: str = None, region_id: str = None, q: str = None, need_all: str = None,
                  offset: str = None, count: str = None) -> dict:
        """
        Возвращает список городов.

        :param country_id: идентификатор страны, полученный database.getCountries.
        :param region_id: идентификатор региона, города которого необходимо получить.
        :param q:  поискового запроса. Например, Санкт.  Максимальная длина строки — 15 символов.
        :param need_all:   1 – возвращать все города.  0 – возвращать только основные города.
        :param offset: отступ, необходимый для получения определенного подмножества городов.
        :param count: количество городов, которые необходимо вернуть.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих города, в поле items.  Каждый объект содержит следующие поля:   id (integer) —
            идентификатор города;  title (string) — название города.   Объект может содержать дополнительные поля:
            area (string) — область;  region (string) — регион.   Если не задан параметр q, то будет возвращен список
            самых крупных городов в заданной стране. Если задан параметр q, то будет возвращен список городов,
            которые релевантны поисковому запросу. Полем important отмечены ключевые города для текущего
            пользователя
        """

        params = locals()
        method_name = self._base_method + 'getCities'
        return self._call(method_name, params)

    def getCitiesById(self, city_ids: str = None) -> dict:
        """
        Возвращает информацию о городах и регионах по их идентификаторам.

        :param city_ids: идентификаторы городов и регионов.

        :return: Возвращает массив объектов, описывающих города.  Каждый объект содержит следующие поля:   id
            (integer) — идентификатор города или региона;  title (string) — название города или региона
        """

        params = locals()
        method_name = self._base_method + 'getCitiesById'
        return self._call(method_name, params)

    def getCountries(self, need_all: str = None, code: str = None, offset: str = None, count: str = None) -> dict:
        """
        Возвращает список стран.

        :param need_all: 1 — вернуть список всех стран.
        :param code: перечисленные через запятую двухбуквенные коды стран в стандарте ISO 3166-1 alpha-2, для
            которых необходимо выдать информацию. Пример значения code: RU,UA,BY
        :param offset: отступ, необходимый для выбора определенного подмножества стран.
        :param count: количество стран, которое необходимо вернуть.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих страны, в поле items.  Каждый объект содержит следующие поля:   id (integer) —
            идентификатор страны;  title (string) — название страны.   Если не заданы параметры need_all и code, то
            возвращается краткий список стран, расположенных наиболее близко к стране текущего пользователя. Если
            задан параметр need_all, то будет возвращен список всех стран. Если задан параметр code, то будут
            возвращены только страны с перечисленными ISO 3166-1 alpha-2 кодами
        """

        params = locals()
        method_name = self._base_method + 'getCountries'
        return self._call(method_name, params)

    def getCountriesById(self, country_ids: str = None) -> dict:
        """
        Возвращает информацию о странах по их идентификаторам

        :param country_ids: идентификаторы стран.

        :return: Возвращает массив объектов, описывающих страны.  Каждый объект содержит следующие поля:   id
            (integer) — идентификатор региона;  title (string) — название региона
        """

        params = locals()
        method_name = self._base_method + 'getCountriesById'
        return self._call(method_name, params)

    def getFaculties(self, university_id: str = None, offset: str = None, count: str = None) -> dict:
        """
        Возвращает список факультетов.

        :param university_id: идентификатор университета, факультеты которого необходимо получить.
        :param offset: отступ, необходимый для получения определенного подмножества факультетов.
        :param count: количество факультетов которое необходимо получить.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих факультеты, в поле items.  Каждый объект содержит следующие поля:   id (integer) —
            идентификатор факультета;  title (string) — название факультета
        """

        params = locals()
        method_name = self._base_method + 'getFaculties'
        return self._call(method_name, params)

    def getMetroStations(self, city_id: str = None, offset: str = None, count: str = None,
                         extended: str = None) -> dict:
        """
        Возвращает список станций метро

        :param city_id: идентификатор города, полученный методом database.getCities.
        :param offset: отступ, необходимый для выбора определенного подмножества станций.
        :param count: количество станций, которое необходимо вернуть.
        :param extended:

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих станции метро, в поле items.  Каждый объект содержит следующие поля:   id (integer)
            — идентификатор;  name (string) — название;  color (string) — цвет линии
        """

        params = locals()
        method_name = self._base_method + 'getMetroStations'
        return self._call(method_name, params)

    def getMetroStationsById(self, station_ids: str = None) -> dict:
        """
        Возвращает информацию об одной или нескольких станциях метро по их идентификаторам.

        :param station_ids: список идентификаторов станций метро

        :return: После успешного выполнения возвращает массив объектов, описывающих станции метро.  Каждый объект
            содержит следующие поля:   id (integer) — идентификатор;  name (string) — название;  color (string) —
            цвет линии
        """

        params = locals()
        method_name = self._base_method + 'getMetroStationsById'
        return self._call(method_name, params)

    def getRegions(self, country_id: str = None, q: str = None, offset: str = None, count: str = None) -> dict:
        """
        Возвращает список регионов.

        :param country_id: идентификатор страны, полученный в методе database.getCountries.
        :param q:  поискового запроса. Например, Лен.
        :param offset: отступ, необходимый для выбора определенного подмножества регионов.
        :param count: количество регионов, которое необходимо вернуть.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих регионы, в поле items.  Каждый объект содержит следующие поля:   id (integer) —
            идентификатор региона;  title (string) — название региона.   Если не задан параметр q, то будет возвращен
            список всех регионов в заданной стране. Если задан параметр q, то будет возвращен список регионов,
            которые релевантны поисковому запросу
        """

        params = locals()
        method_name = self._base_method + 'getRegions'
        return self._call(method_name, params)

    def getSchoolClasses(self, country_id: str = None) -> dict:
        """
        Возвращает список классов, характерных для школ определенной страны.

        :param country_id: идентификатор страны, доступные классы в которой необходимо вернуть.

        :return: Возвращает массив, каждый элемент которого представляет собой пару: идентификатор и строковое
            обозначение класса
        """

        params = locals()
        method_name = self._base_method + 'getSchoolClasses'
        return self._call(method_name, params)

    def getSchools(self, q: str = None, city_id: str = None, offset: str = None, count: str = None) -> dict:
        """
        Возвращает список школ.

        :param q:  поискового запроса. Например, гимназия.
        :param city_id: идентификатор города, школы которого необходимо вернуть.
        :param offset: отступ, необходимый для получения определенного подмножества школ.
        :param count: количество школ, которое необходимо вернуть.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих школы, в поле items.  Каждый объект содержит следующие поля:   id (integer) —
            идентификатор школы;  title (string) — название школы
        """

        params = locals()
        method_name = self._base_method + 'getSchools'
        return self._call(method_name, params)

    def getUniversities(self, q: str = None, country_id: str = None, city_id: str = None, offset: str = None,
                        count: str = None) -> dict:
        """
        Возвращает список высших учебных заведений.

        :param q:  поискового запроса. Например, СПБ.
        :param country_id: идентификатор страны, учебные заведения которой необходимо вернуть.
        :param city_id: идентификатор города, учебные заведения которого необходимо вернуть.
        :param offset: отступ, необходимый для получения определенного подмножества учебных заведений.
        :param count: количество учебных заведений, которое необходимо вернуть.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих университеты, в поле items.  Каждый объект содержит следующие поля:   id (integer)
            — идентификатор университета;  title (string) — название университета
        """

        params = locals()
        method_name = self._base_method + 'getUniversities'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Pages(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Pages, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'pages.'

    def clearCache(self, url: str = None) -> dict:
        """
        Позволяет очистить кеш отдельных внешних страниц, которые могут быть прикреплены к записям ВКонтакте. После
        очистки кеша при последующем прикреплении ссылки к записи, данные о странице будут обновлены.

        :param url: Адрес страницы, закешированную версию которой необходимо очистить

        :return: При удачной очистке кеша – метод возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'clearCache'
        return self._call(method_name, params)

    def get(self, owner_id: str = None, page_id: str = None, site_preview: str = None,
            title: str = None, need_source: str = None, need_html: str = None) -> dict:
        # global: str = None,
        """
        Возвращает информацию о вики-странице.

        :param owner_id: идентификатор владельца вики-страницы.
        :param page_id: идентификатор вики-страницы.
        :param global: 1 — требуется получить информацию о глобальной вики-странице.
        :param site_preview: 1 — получаемая wiki страница является предпросмотром для прикрепленной ссылки.
        :param title: название страницы.
        :param need_source: 1 — требуется вернуть содержимое страницы в вики-формате.
        :param need_html: 1 — требуется вернуть html-представление страницы.

        :return: Возвращает информацию о вики-странице в виде объекта page.  Если был задан параметр need_source
            равный 1, дополнительно будет возвращено поле source.  Если был задан параметр need_html равный 1,
            дополнительно будет возвращено поле html
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getHistory(self, page_id: str = None, group_id: str = None, user_id: str = None) -> dict:
        """
        Возвращает список всех старых версий вики-страницы.

        :param page_id: идентификатор вики-страницы.
        :param group_id: идентификатор сообщества, которому принадлежит вики-страница.
        :param user_id: идентификатор пользователя, создавшего вики-страницу.

        :return: Возвращает массив объектов page_version, имеющих следующую структуру:   id — идентификатор
            версии страницы;  length длина версии страницы в байтах;  edited — дата редактирования страницы;
            editor_id — идентификатор редактора;  editor_name — имя редактора
        """

        params = locals()
        method_name = self._base_method + 'getHistory'
        return self._call(method_name, params)

    def getTitles(self, group_id: str = None) -> dict:
        """
        Возвращает список вики-страниц в группе.

        :param group_id: идентификатор сообщества, которому принадлежит вики-страница.

        :return: Возвращает массив объектов вики-страниц
        """

        params = locals()
        method_name = self._base_method + 'getTitles'
        return self._call(method_name, params)

    def getVersion(self, version_id: str = None, group_id: str = None, user_id: str = None,
                   need_html: str = None) -> dict:
        """
        Возвращает текст одной из старых версий страницы.

        :param version_id: идентификатор версии.
        :param group_id: идентификатор сообщества, которому принадлежит вики-страница.
        :param user_id: идентификатор пользователя, который создал страницу.
        :param need_html: определяет, требуется ли в ответе html-представление вики-страницы.

        :return: Возвращает объект вики-страницы
        """

        params = locals()
        method_name = self._base_method + 'getVersion'
        return self._call(method_name, params)

    def parseWiki(self, text: str = None, group_id: str = None) -> dict:
        """
        Возвращает html-представление вики-разметки.

        :param text: текст в вики-формате.
        :param group_id: идентификатор группы, в контексте которой интерпретируется данная страница.

        :return: В случае успеха возвращает экранированный html, соответствующий вики-разметке
        """

        params = locals()
        method_name = self._base_method + 'parseWiki'
        return self._call(method_name, params)

    def save(self, text: str = None, page_id: str = None, group_id: str = None, user_id: str = None,
             title: str = None) -> dict:
        """
        Сохраняет текст вики-страницы.

        :param text: новый текст страницы в вики-формате.
        :param page_id: идентификатор вики-страницы. Вместо page_id может быть передан параметр title.
        :param group_id: идентификатор сообщества, которому принадлежит вики-страница.
        :param user_id: идентификатор пользователя, создавшего вики-страницу.
        :param title: название вики-страницы.

        :return: В случае успеха возвращает id созданной страницы
        """

        params = locals()
        method_name = self._base_method + 'save'
        return self._call(method_name, params)

    def saveAccess(self, page_id: str = None, group_id: str = None, user_id: str = None, view: str = None,
                   edit: str = None) -> dict:
        """
        Сохраняет новые настройки доступа на чтение и редактирование вики-страницы.

        :param page_id: идентификатор вики-страницы.
        :param group_id: идентификатор сообщества, которому принадлежит вики-страница.
        :param user_id: идентификатор пользователя, создавшего вики-страницу.
        :param view: значение настройки доступа на чтение. Возможные значения:   2 — просматривать страницу могут
            все;  1 — только участники сообщества;  0 — только руководители сообщества.
        :param edit: значение настройки доступа на редактирование. Возможные значения:   2 — редактировать
            страницу могут все;  1 — только участники сообщества;  0 — только руководители сообщества.

        :return: В случае успеха возвращает id страницы, доступ к которой был отредактирован
        """

        params = locals()
        method_name = self._base_method + 'saveAccess'
        return self._call(method_name, params)




from ApiMethod import ApiMethod


class Notes(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Notes, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'notes.'

    def add(self, title: str = None, text: str = None, privacy_view: str = None, privacy_comment: str = None) -> dict:
        """
        Создает новую заметку у текущего пользователя.

        :param title: заголовок заметки.
        :param text: текст заметки.
        :param privacy_view: настройки приватности просмотра заметки в специальном формате.
        :param privacy_comment: настройки приватности комментирования заметки в специальном формате.

        :return: После успешного выполнения возвращает идентификатор созданной заметки (nid)
        """

        params = locals()
        method_name = self._base_method + 'add'
        return self._call(method_name, params)

    def createComment(self, note_id: str = None, owner_id: str = None, reply_to: str = None, message: str = None,
                      guid: str = None) -> dict:
        """
        Добавляет новый комментарий к заметке.

        :param note_id: идентификатор заметки.
        :param owner_id: идентификатор владельца заметки.
        :param reply_to: идентификатор пользователя, ответом на комментарий которого является добавляемый
            комментарий (не передаётся, если комментарий не является ответом).
        :param message: текст комментария.
        :param guid: уникальный идентификатор, предназначенный для предотвращения повторной отправки одинакового
            комментария.

        :return: После успешного выполнения возвращает идентификатор созданного комментария (cid)
        """

        params = locals()
        method_name = self._base_method + 'createComment'
        return self._call(method_name, params)

    def delete(self, note_id: str = None) -> dict:
        """
        Удаляет заметку текущего пользователя.

        :param note_id: идентификатор заметки.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def deleteComment(self, comment_id: str = None, owner_id: str = None) -> dict:
        """
        Удаляет комментарий к заметке.

        :param comment_id: идентификатор комментария.
        :param owner_id: идентификатор владельца заметки.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteComment'
        return self._call(method_name, params)

    def edit(self, note_id: str = None, title: str = None, text: str = None, privacy_view: str = None,
             privacy_comment: str = None) -> dict:
        """
        Редактирует заметку текущего пользователя.

        :param note_id: идентификатор заметки.
        :param title: заголовок заметки.
        :param text: текст заметки.
        :param privacy_view: настройки приватности просмотра заметки в специальном формате.
        :param privacy_comment: настройки приватности комментирования заметки в специальном формате.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'edit'
        return self._call(method_name, params)

    def editComment(self, comment_id: str = None, owner_id: str = None, message: str = None) -> dict:
        """
        Редактирует указанный комментарий у заметки.

        :param comment_id: идентификатор комментария.
        :param owner_id: идентификатор владельца заметки.
        :param message: новый текст комментария.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editComment'
        return self._call(method_name, params)

    def get(self, note_ids: str = None, user_id: str = None, offset: str = None, count: str = None,
            sort: str = None) -> dict:
        """
        Возвращает список заметок, созданных пользователем.

        :param note_ids: идентификаторы заметок, информацию о которых необходимо получить.
        :param user_id: идентификатор пользователя, информацию о заметках которого требуется получить.
        :param offset: смещение, необходимое для выборки определенного подмножества заметок.
        :param count: количество заметок, информацию о которых необходимо получить.
        :param sort: сортировка результатов (0 — по дате создания в порядке убывания, 1 - по дате создания в
            порядке возрастания).

        :return: После успешного выполнения возвращает список объектов заметок
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getById(self, note_id: str = None, owner_id: str = None, need_wiki: str = None) -> dict:
        """
        Возвращает заметку по её id.

        :param note_id: идентификатор заметки.
        :param owner_id: идентификатор владельца заметки.
        :param need_wiki: определяет, требуется ли в ответе wiki-представление заметки (работает, только если
            запрашиваются заметки текущего пользователя).

        :return: После успешного выполнения возвращает список объектов заметок с дополнительными полями:
            privacy — уровень доступа к заметке (0 — все пользователи, 1 — только друзья, 2 — друзья и друзья друзей,
            3 — только пользователь);  comment_privacy — уровень доступа к комментированию заметки (0 — все
            пользователи, 1 — только друзья, 2 — друзья и друзья друзей, 3 — только пользователь);  can_comment —
            может ли текущий пользователь комментировать заметку (1 — может, 0 — не может)
        """

        params = locals()
        method_name = self._base_method + 'getById'
        return self._call(method_name, params)

    def getComments(self, note_id: str = None, owner_id: str = None, sort: str = None, offset: str = None,
                    count: str = None) -> dict:
        """
        Возвращает список комментариев к заметке.

        :param note_id: идентификатор заметки.
        :param owner_id: идентификатор владельца заметки.
        :param sort: сортировка результатов (0 — по дате добавления в порядке возрастания, 1 — по дате добавления
            в порядке убывания).
        :param offset: смещение, необходимое для выборки определенного подмножества комментариев.
        :param count: количество комментариев, которое необходимо получить.

        :return: Возвращает массив объектов comment, каждый из которых содержит следующие поля:   id —
            идентификатор комментария;  uid — идентификатор автора комментария;  nid — идентификатор заметки;  oid —
            идентификатор владельца заметки;  date — дата добавления комментария в формате unixtime;  message — текст
            комментария;  reply_to — идентификатор пользователя, в ответ на комментарий которого был оставлен текущий
            комментарий (если доступно)
        """

        params = locals()
        method_name = self._base_method + 'getComments'
        return self._call(method_name, params)

    def restoreComment(self, comment_id: str = None, owner_id: str = None) -> dict:
        """
        Восстанавливает удалённый комментарий.

        :param comment_id: идентификатор удаленного комментария.
        :param owner_id: идентификатор владельца заметки.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'restoreComment'
        return self._call(method_name, params)




from ApiMethod import ApiMethod


class Search(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Search, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'search.'

    def getHints(self, q: str = None, offset: str = None, limit: str = None, filters: str = None, fields: str = None,
                 search_global: str = None) -> dict:
        """
        Метод позволяет получить результаты быстрого поиска по произвольной подстроке

        :param q: текст запроса, результаты которого нужно получить
        :param offset: смещение для выборки определённого подмножества результатов.
        :param limit: ограничение на количество возвращаемых результатов.
        :param filters: Перечисленные через запятую типы данных, которые необходимо вернуть. Возможные значения:
            friends – друзья пользователя;  idols – подписки пользователя;  publics – публичные страницы, на которые
            подписан пользователь;  groups – группы пользователя;  events – встречи пользователя;  correspondents –
            люди, с которыми пользователь имеет переписку;  mutual_friends – люди, у которых есть общие друзья с
            текущим пользователем (этот фильтр позволяет получить не всех пользователей, имеющих общих друзей).    По
            умолчанию возвращаются все.
        :param fields: дополнительные поля профилей и сообществ для получения.
        :param search_global: 1 — к результатам поиска добавляются результаты глобального поиска по всем
            пользователям и группам.

        :return: После успешного выполнения возвращает массив объектов, каждый из которых содержит стандартные
            поля type, section, description и соответствующий объект с набором дополнительных полей.  type integerтип
            объекта. Возможные значения:   group — сообщество;  profile — профиль.   group (для type = group)
            objectданные о сообществе. Объект, который содержит поля:   id (integer) — идентификатор сообщества;
            name (string) — название сообщества;  screen_name (string) — короткий адрес;  is_closed (integer) —
            информация о том, является ли группа/встреча закрытой (0 — открытая, 1 — закрытая, 2 — частная);
            is_admin (integer, [0,1]) — информация о том, является ли текущий пользователь администратором сообщества
            (1 — является, 0 — не является);  is_member (integer, [0,1]) — информация о том, является ли текущий
            пользователь участником сообщества (1 — является, 0 — не является);  type (string) — тип сообщества.
            Возможные значения:   group — группа;  page — публичная страница;  event — встреча);   photo (string) —
            URL квадратной фотографии сообщества с размером 50х50px;  photo_medium (string) — URL квадратной
            фотографии сообщества с размером 100х100px;  photo_big (string) — URL фотографии сообщества в
            максимальном доступном размере. profile (для type = profile) objectданные о профиле. Объект, который
            содержит поля:   id (integer) — идентификатор пользователя;  first_name (string) — имя пользователя;
            last_name (string) — фамилия пользователя. section  stringтип объекта. Возможные значения для сообществ:
            groups — группы;  events — мероприятия;  publics — публичные страницы.  Возможные значения для профилей:
            correspondents — собеседники по переписке;  people — популярные пользователи;  friends — друзья;
            mutual_friends — пользователи, имеющие общих друзей с текущим. description  stringописание объекта (для
            сообществ — тип и число участников, например, Group, 269,136 members, для профилей друзей или
            пользователями, которые не являются возможными друзьями — название университета или город, для профиля
            текущего пользователя — That's you, для профилей возможных друзей — N mutual friends). global  integer,
            [1]поле возвращается, если объект был найден в глобальном поиске, всегда содержит 1
        """

        params = locals()
        method_name = self._base_method + 'getHints'
        return self._call(method_name, params)




from ApiMethod import ApiMethod


class Stats(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Stats, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'stats.'

    def get(self, group_id: str = None, app_id: str = None, timestamp_from: str = None, timestamp_to: str = None,
            interval: str = None, intervals_count: str = None, filters: str = None, stats_groups: str = None,
            extended: str = None) -> dict:
        """
        Возвращает статистику сообщества или приложения.

        :param group_id: идентификатор сообщества.
        :param app_id: идентификатор приложения.
        :param timestamp_from: начало периода статистики в Unixtime.
        :param timestamp_to: окончание периода статистики в Unixtime.
        :param interval: временные интервалы. Возможные значения: day, week, month, year, all. По умолчанию: day.
        :param intervals_count: количество интервалов времени.
        :param filters:
        :param stats_groups: фильтр для получения данных по конкретному блоку статистики сообщества. Возможные
            значения: visitors, reach, activity.
        :param extended: 1 — возвращать дополнительно агрегированные данные в результатах.

        :return: После успешного выполнения возвращает объект с данными статистики
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getPostReach(self, owner_id: str = None, post_ids: str = None) -> dict:
        """
        Возвращает статистику для записи на стене.

        :param owner_id: идентификатор сообщества — владельца записи. Указывается со знаком «минус».
        :param post_ids:

        :return: После успешного выполнения возвращает данные о статистике записи в виде объекта, который
            содержит следующие поля:  reach_subscribers  integerохват подписчиков. reach_total  integerсуммарный
            охват. reach_ads  integerрекламный охват (если запись продвигалась с помощью таргетированной рекламы).
            reach_viral  integerвиральный охват (если запись продвигалась с помощью таргетированной рекламы).. links
            integerпереходы по ссылке. to_group  integerпереходы в сообщество. join_group  integerвступления в
            сообщество. report  integerколичество жалоб на запись. hide  integerколичество скрывших запись.
            unsubscribe  integerколичество отписавшихся участников
        """

        params = locals()
        method_name = self._base_method + 'getPostReach'
        return self._call(method_name, params)

    def trackVisitor(self) -> dict:
        """
        Добавляет данные о текущем сеансе в статистику посещаемости приложения.

        :return: В случае успешной обработки данных метод вернет 1
        """

        params = locals()
        method_name = self._base_method + 'trackVisitor'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Widgets(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Widgets, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'widgets.'

    def getComments(self, widget_api_id: str = None, url: str = None, page_id: str = None, order: str = None,
                    fields: str = None, offset: str = None, count: str = None) -> dict:
        """
        Получает список комментариев к странице, оставленных через Виджет комментариев.

        :param widget_api_id: Идентификатор приложения/сайта, с которым инициализируются виджеты.
        :param url: URL-адрес страницы.
        :param page_id: внутренний идентификатор страницы в приложении/сайте (в случае, если для инициализации
            виджетов использовался параметр page_id).
        :param order: тип сортировки комментариев. Возможные значения: date, likes, last_comment. Значение по
            умолчанию - date.
        :param fields: перечисленные через запятую поля анкет необходимые для получения. Если среди полей
            присутствует replies, будут возвращены последние комментарии второго уровня для каждого комментария
            первого уровня.
        :param offset: смещение необходимое для выборки определенного подмножества комментариев. По умолчанию 0.
        :param count: количество возвращаемых записей.

        :return: В случае успеха возвращает объект со следующими полями:   count — общее количество комментариев
            первого уровня к странице (без учета ограничений из входного параметра count).  posts — список
            комментариев первого уровня. Каждый элемент списка имеет структуру, схожую с объектами post из
            результатов метода wall.get. Помимо этого:   В случае, если среди необходимых полей было указано replies,
            в поле comments.replies будет содержаться список комментариев второго уровня. Каждый элемент этого списка
            имеет структуру, схожую с объектами comment из результатов метода wall.getComments.  В случае, если были
            указаны любые другие необходимые поля анкет, в каждом элементе post и comment будет поле user, содержащее
            соответствующую информацию об авторе комментария
        """

        params = locals()
        method_name = self._base_method + 'getComments'
        return self._call(method_name, params)

    def getPages(self, widget_api_id: str = None, order: str = None, period: str = None, offset: str = None,
                 count: str = None) -> dict:
        """
        Получает список страниц приложения/сайта, на которых установлен Виджет комментариев или «Мне нравится».

        :param widget_api_id: идентификатор приложения/сайта, с которым инициализируются виджеты.
        :param order: Тип сортировки страниц. Возможные значения: date, comments, likes, friend_likes.
        :param period: Период выборки. Возможные значения: day, week, month, alltime.
        :param offset: смещение необходимое для выборки определенного подмножества комментариев. По умолчанию 0.
        :param count: количество возвращаемых записей.

        :return: В случае успеха возвращает объект со следующими полями:   count — общее количество страниц (без
            учета ограничений входного параметра count)  pages — список объектов-страниц Каждый объект, описывающий
            страницу, имеет следующие поля:   id — идентификатор страницы в системе;  title — заголовок страницы
            (берется из мета-тегов на странице или задается параметром pageTitle при инициализации)  description —
            краткое описание страницы (берется из мета-тегов на странице или задается параметром pageDescription при
            инициализации);  photo — объект, содержащий фотографию-миниатюру страницы (берется из мета-тегов на
            странице или задается параметром pageImage при инициализации)  url — абсолютный адрес страницы;  likes —
            объект, содержащий поле count — количество отметок «Мне нравится» к странице. Для получения списка
            пользователей, отметивших страницу можно использовать метод likes.getList с параметром type равным
            site_page;  comments — объект, содержащий поле count — количество комментариев к странице внутри виджета.
            Для получения списка комментариев можно использовать метод widgets.getComments;  date — дата первого
            обращения к виджетам на странице  page_id — внутренний идентификатор страницы в приложении/на сайте (в
            случае, если при инициализации виджетов использовался параметр page_id)
        """

        params = locals()
        method_name = self._base_method + 'getPages'
        return self._call(method_name, params)
